/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.common.constant;

import org.springblade.core.launch.constant.AppConstant;

/**
 * 通用常量
 *
 * @author Chill
 */
public interface CommonConstant {

	/**
	 * app name
	 */
	String APPLICATION_NAME = AppConstant.APPLICATION_NAME_PREFIX + "api";

	/**
	 * sword 系统名
	 */
	String SWORD_NAME = "sword";

	/**
	 * saber 系统名
	 */
	String SABER_NAME = "saber";

	/**
	 * 顶级父节点id
	 */
	Long TOP_PARENT_ID = 0L;

	/**
	 * 顶级父节点名称
	 */
	String TOP_PARENT_NAME = "顶级";

	/**
	 * 未封存状态值
	 */
	Integer NOT_SEALED_ID = 0;

	/**
	 * 默认密码
	 */
	String DEFAULT_PASSWORD = "123456";

	/**
	 * 默认密码参数值
	 */
	String DEFAULT_PARAM_PASSWORD = "account.initPassword";

	/**
	 * 默认排序字段
	 */
	String SORT_FIELD = "sort";

	/**
	 * 数据权限类型
	 */
	Integer DATA_SCOPE_CATEGORY = 1;

	/**
	 * 接口权限类型
	 */
	Integer API_SCOPE_CATEGORY = 2;


	String API_URL = "v1";

	/**
	 * 默认用户头像
	 */
	String DEFAULT_AVATAR = "user:default:avatar";

	/**
	 * 默认角色
	 */
	String DEFAULT_ROLD = "user:default:role";


	/**
	 * 默认部门
	 */
	String DEFAULT_DEPT = "user:default:dept";

	/**
	 * 默认岗位
	 */
	String DEFAULT_POST = "user:default:post";

	/**
	 * 默认信誉分
	 */
	String DEFAULT_CREDIT_SCORE = "user:default:creditScore";

	/**
	 * 默认注册送红色积分数
	 */
	String DEFAULT_REGISTER_INTEGRAL = "user:default:registerIntegral";

	/**
	 * 默认服务费比例
	 */
	String DEFAULT_SERVERS_RATIO = "user:default:servesRatio";

	/**
	 * 默认积分手续费
	 */
	String DEFAULT_SCORE_RATIO = "default:score:ratio";

	/**
	 * 广告轮播默认条数
	 */
	String DEFAULT_ADS_LIMIT = "default:ads:limit";

	/**
	 * 首页默认抢购专区查询条数
	 */
	String DEFAULT_CONSIGN_LIMIT = "default:consign:limit";

	/**
	 * 服务器服务域名
	 */
	String DEFAULT_SERVICE_DOMAIN = "default:service:domain";

	/**
	 * 寄售1天的取得价比
	 */
	String DEFAULT_CONDIGN_RATIO_T1 = "default:consign:ratio:t1";

	/**
	 * 寄售2天的取得价比
	 */
	String DEFAULT_CONDIGN_RATIO_T2 = "default:consign:ratio:t2";

	/**
	 * 寄售3天的取得价比
	 */
	String DEFAULT_CONDIGN_RATIO_T3 = "default:consign:ratio:t3";

	/**
	 * 参与人数调整比例
	 */
	String DEFAULT_CONDIGN_TURNOUT = "default:consign:turnout";

	/**
	 * 最大可抢次数
	 */
	String DEFAULT_CONDIGN_COUNT = "default:consign:count";

	/**
	 * 邀请好友注册完善资料（+5信誉分）
	 */
	String SCORE_USER_REGISTER = "score:user:register";

	/**
	 * 每完成一次进货（+20信誉分）
	 */
	String SCORE_CONSIGN_EVERY_TIME = "score:consign:everyTime";

	/**
	 * 减少进货场次（-30信誉分）
	 */
	String SCORE_CONSIGN_SUB = "score:consign:sub";

	/**
	 * 500信誉分以上或含有500信誉分 - 完成进货+2信誉分，
	 */
	String SCORE_CONSIGN_OVER = "score:consign:in";

	/**
	 * 500信誉分以上或含有500信誉分 - 邀请好友注册完善资料+1信誉分
	 */
	String SCORE_CONSIGN_REGISTER = "score:consign:register";

	/**
	 * 场次 - 定时时间
	 */
	String TASK_SCHEDULING_TIME = "default:task:time";

	/**
	 * 预授权退款（解冻） 定时时间
	 */
	String TASK_GRANT_TIME = "task:grant:time";


	/**
	 * 增益时间
	 */
	String GAIN_CONSIGN_TIME = "gain:consign:time";

	/**
	 * 加速积分比例
	 */
	String INTEGRAL_ACCELERATE_RATIO = "integral:accelerate:ratio";
	/**
	 * 交割积分比例
	 */
	String CONSIGN_ACCELERATE_RATIO = "consign:accelerate:ratio";

	/**
	 * 扣除收益比率
	 */
	String PLATFORM_TAX_RATIO = "platform:tax:ratio";

	/**
	 * 加速提现比例
	 */
	String ACCELERATE_WITHDRAWAL_RATIO = "accelerate:withdrawal:ratio";
	/**
	 * 红包提现扣除手续费提现比例
	 */
	String RED_WITHDRAWAL_RATIO = "red:withdrawal:ratio";

	/**
	 * 加速封顶金额
	 */
	String ACCELERATE_WITHDRAWAL_CAPS = "accelerate:withdrawal:caps";

	/**
	 * 提现额度
	 */
	String NORMAL_WITHDRAWAL_CAPS = "normal:withdrawal:caps";

	/**
	 * 进货模块使用支付方式
	 */
	String PAY_TYPE_LIST = "pay:type:list";


	String ALI_PAY = "aliPay";

	String WX_PAY = "wxPay";

}
