/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.api.request;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import javax.validation.constraints.NotEmpty;
import java.io.Serializable;

/**
 * 地址请求实体
 *
 * @author xuwei
 */
@Data
@ApiModel(value = "新增用户地址实体对象", description = "请求实体类")
public class AddressSaveRequest implements Serializable {

	private static final long serialVersionUID = 1L;

	@ApiModelProperty(value = "用户id")
	private Long userId;

	@NotEmpty(message = "姓名不能为空")
	@ApiModelProperty(value = "收货人姓名")
	private String realName;

	@NotEmpty(message = "手机号不能为空")
	@ApiModelProperty(value = "收货人电话")
	private String phone;

	@NotEmpty(message = "请选择地址")
	@ApiModelProperty(value = "收货人所在省")
	private String province;

	@NotEmpty(message = "请选择地址")
	@ApiModelProperty(value = "收货人所在市")
	private String city;

	@NotEmpty(message = "请选择地址")
	@ApiModelProperty(value = "收货人所在区")
	private String district;

//	@NotEmpty(message = "请选择街道")
	@ApiModelProperty(value = "收货人所在街道")
	private String street;

	@ApiModelProperty(value = "收货人所在市code")
	private Integer districtCode;

	@ApiModelProperty(value = "收货人详细地址" )
	private String detail;

	@ApiModelProperty(value = "邮编")
	private String postCode;

	@ApiModelProperty(value = "经度")
	private String lng;

	@ApiModelProperty(value = "纬度")
	private String lat;

	@ApiModelProperty(value = "默认标识")
	private Integer defaultState;


}
