/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.api.request;

import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import org.springframework.format.annotation.DateTimeFormat;

import java.io.Serializable;
import java.util.Date;

/**
 * 视图实体类
 *
 * @author Chill
 */
@Data
@ApiModel(value = "UserAppVO对象", description = "UserAppVO对象")
public class UserAppUpdateRequest implements Serializable {
	private static final long serialVersionUID = 1L;

	@ApiModelProperty(value = "用户ID")
	private Long userId;

	/**
	 * 昵称
	 */
	@ApiModelProperty(value = "昵称")
	private String name;

	/**
	 * 头像
	 */
	@ApiModelProperty(value = "头像")
	private String avatar;

	/**
	 * 生日
	 */
	@DateTimeFormat(pattern = "yyyy-MM-dd")
	@JsonFormat(pattern = "yyyy-MM-dd")
	@ApiModelProperty(value = "生日,格式yyyy-MM-dd")
	private Date birthday;
	/**
	 * 性别
	 */
	@ApiModelProperty(value = "性别：1男，2女")
	private Integer sex;

	/**
	 * 二维码
	 */
	@ApiModelProperty(value = "二维码")
	private String wxQrcode;

	/**
	 * 电话
	 */
	@ApiModelProperty(value = "电话")
	private String phone;
}
