/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.business.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.AllArgsConstructor;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springblade.modules.business.entity.FacilityCargoWay;
import org.springblade.modules.business.service.IFacilityCargoWayService;
import org.springblade.modules.business.vo.FacilityCargoWayVO;
import org.springblade.modules.business.wrapper.FacilityCargoWayWrapper;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;

/**
 * 售货机货表 控制器
 *
 * @author BladeX
 * @since 2024-07-16
 */
@RestController
@AllArgsConstructor
@RequestMapping("facilitycargoway")
@Api(value = "售货机货表", tags = "售货机货表接口")
public class FacilityCargoWayController extends BladeController {

	private final IFacilityCargoWayService facilityCargoWayService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入facilityCargoWay")
	public R<FacilityCargoWayVO> detail(FacilityCargoWay facilityCargoWay) {
		FacilityCargoWay detail = facilityCargoWayService.getOne(Condition.getQueryWrapper(facilityCargoWay));
		return R.data(FacilityCargoWayWrapper.build().entityVO(detail));
	}

	/**
	 * 分页 售货机货表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入facilityCargoWay")
	public R<IPage<FacilityCargoWayVO>> list(FacilityCargoWay facilityCargoWay, Query query) {
		IPage<FacilityCargoWay> pages = facilityCargoWayService.page(Condition.getPage(query), Condition.getQueryWrapper(facilityCargoWay));
		return R.data(FacilityCargoWayWrapper.build().pageVO(pages));
	}


	/**
	 * 自定义分页 售货机货表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入facilityCargoWay")
	public R<IPage<FacilityCargoWayVO>> page(FacilityCargoWayVO facilityCargoWay, Query query) {
		IPage<FacilityCargoWayVO> pages = facilityCargoWayService.selectFacilityCargoWayPage(Condition.getPage(query), facilityCargoWay);
		return R.data(pages);
	}

	/**
	 * 新增 售货机货表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入facilityCargoWay")
	public R save(@Valid @RequestBody FacilityCargoWay facilityCargoWay) {
		return R.status(facilityCargoWayService.save(facilityCargoWay));
	}

	/**
	 * 修改 售货机货表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入facilityCargoWay")
	public R update(@Valid @RequestBody FacilityCargoWay facilityCargoWay) {
		return R.status(facilityCargoWayService.updateById(facilityCargoWay));
	}

	/**
	 * 新增或修改 售货机货表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入facilityCargoWay")
	public R submit(@Valid @RequestBody FacilityCargoWay facilityCargoWay) {
		return R.status(facilityCargoWayService.saveOrUpdate(facilityCargoWay));
	}

	
	/**
	 * 删除 售货机货表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(facilityCargoWayService.removeByIds(Func.toLongList(ids)));
	}

	
}
