/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.business.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.business.entity.Shop;
import org.springblade.modules.business.vo.ShopVO;
import org.springblade.modules.business.wrapper.ShopWrapper;
import org.springblade.modules.business.service.IShopService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 门店表 控制器
 *
 * @author BladeX
 * @since 2024-07-16
 */
@RestController
@AllArgsConstructor
@RequestMapping("business/shop")
@Api(value = "门店表", tags = "门店表接口")
public class ShopController extends BladeController {

	private final IShopService shopService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入shop")
	public R<ShopVO> detail(Shop shop) {
		Shop detail = shopService.getOne(Condition.getQueryWrapper(shop));
		return R.data(ShopWrapper.build().entityVO(detail));
	}

	/**
	 * 分页 门店表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入shop")
	public R<IPage<ShopVO>> list(Shop shop, Query query) {
		IPage<Shop> pages = shopService.page(Condition.getPage(query), Condition.getQueryWrapper(shop));
		return R.data(ShopWrapper.build().pageVO(pages));
	}


	/**
	 * 自定义分页 门店表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入shop")
	public R<IPage<ShopVO>> page(ShopVO shop, Query query) {
		IPage<ShopVO> pages = shopService.selectShopPage(Condition.getPage(query), shop);
		return R.data(pages);
	}

	/**
	 * 新增 门店表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入shop")
	public R save(@Valid @RequestBody Shop shop) {
		return R.status(shopService.save(shop));
	}

	/**
	 * 修改 门店表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入shop")
	public R update(@Valid @RequestBody Shop shop) {
		return R.status(shopService.updateById(shop));
	}

	/**
	 * 新增或修改 门店表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入shop")
	public R submit(@Valid @RequestBody Shop shop) {
		return R.status(shopService.saveOrUpdate(shop));
	}

	
	/**
	 * 删除 门店表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(shopService.removeByIds(Func.toLongList(ids)));
	}

	
}
