/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.business.service.impl;

import cn.hutool.core.collection.CollUtil;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import org.springblade.common.base.BaseEntity;
import org.springblade.modules.business.entity.Shop;
import org.springblade.modules.business.vo.ShopVO;
import org.springblade.modules.business.mapper.ShopMapper;
import org.springblade.modules.business.service.IShopService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.core.metadata.IPage;

import java.util.List;
import java.util.stream.Collectors;

/**
 * 门店表 服务实现类
 *
 * @author BladeX
 * @since 2024-07-16
 */
@Service
public class ShopServiceImpl extends ServiceImpl<ShopMapper, Shop> implements IShopService {

	@Override
	public IPage<ShopVO> selectShopPage(IPage<ShopVO> page, ShopVO shop) {
		return page.setRecords(baseMapper.selectShopPage(page, shop));
	}

	@Override
	public List<Long> getMerchantShopIds(Long userId) {
		List<Shop> shops = baseMapper.selectList(Wrappers.lambdaQuery(Shop.class).eq(Shop::getMerchantId, userId));
		if (CollUtil.isNotEmpty(shops)) {
			return shops.stream().map(BaseEntity::getId).collect(Collectors.toList());
		}
		return null;
	}

}
