/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.distribution.controller;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.common.base.BaseEntity;
import org.springblade.core.log.logger.BladeLogger;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.distribution.entity.DistributionConfig;
import org.springblade.modules.distribution.vo.DistributionConfigVO;
import org.springblade.modules.distribution.wrapper.DistributionConfigWrapper;
import org.springblade.modules.distribution.service.IDistributionConfigService;
import org.springblade.core.boot.ctrl.BladeController;

import java.sql.Wrapper;

/**
 * 分销配置表列表 控制器
 *
 * @author BladeX
 * @since 2023-06-04
 */
@RestController
@AllArgsConstructor
@RequestMapping("config/distributionconfig")
@Api(value = "分销配置表列表", tags = "分销配置表列表接口")
public class DistributionConfigController extends BladeController {

	private final IDistributionConfigService distributionConfigService;
	private final BladeLogger bladeLogger;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入distributionConfig")
	public R<DistributionConfig> detail() {
		DistributionConfig detail = distributionConfigService.getOne(Wrappers.lambdaQuery(DistributionConfig.class).eq(BaseEntity::getIsDelete,0));
		return R.data(detail);
	}

	/**
	 * 分页 分销配置表列表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入distributionConfig")
	public R<IPage<DistributionConfigVO>> list(DistributionConfig distributionConfig, Query query) {
		IPage<DistributionConfig> pages = distributionConfigService.page(Condition.getPage(query), Condition.getQueryWrapper(distributionConfig));
		return R.data(DistributionConfigWrapper.build().pageVO(pages));
	}


	/**
	 * 自定义分页 分销配置表列表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入distributionConfig")
	public R<IPage<DistributionConfigVO>> page(DistributionConfigVO distributionConfig, Query query) {
		IPage<DistributionConfigVO> pages = distributionConfigService.selectDistributionConfigPage(Condition.getPage(query), distributionConfig);
		return R.data(pages);
	}

	/**
	 * 新增 分销配置表列表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入distributionConfig")
	public R save(@Valid @RequestBody DistributionConfig distributionConfig) {
		return R.status(distributionConfigService.save(distributionConfig));
	}

	/**
	 * 修改 分销配置表列表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入distributionConfig")
	public R update(@Valid @RequestBody DistributionConfig distributionConfig) {
		return R.status(distributionConfigService.updateById(distributionConfig));
	}

	/**
	 * 新增或修改 分销配置表列表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入distributionConfig")
	public R submit(@Valid @RequestBody DistributionConfig distributionConfig) {
		bladeLogger.info("分销配置修改记录", "开启状态:" + distributionConfig.getIsOpen() + ", 分销关系绑定天数:" + distributionConfig.getBindingDays() +
				", 分销结算天数:" + distributionConfig.getSettleDays() + ", 订单分销比例: " + distributionConfig.getProportion());
		return R.status(distributionConfigService.saveOrUpdate(distributionConfig));
	}

	
	/**
	 * 删除 分销配置表列表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(distributionConfigService.removeByIds(Func.toLongList(ids)));
	}

	
}
