/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.finance.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.finance.entity.AfterSalesReason;
import org.springblade.modules.finance.vo.AfterSalesReasonVO;
import org.springblade.modules.finance.wrapper.AfterSalesReasonWrapper;
import org.springblade.modules.finance.service.IAfterSalesReasonService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 售后原因 控制器
 *
 * @author BladeX
 * @since 2023-06-13
 */
@RestController
@AllArgsConstructor
@RequestMapping("finance/aftersalesreason")
@Api(value = "售后原因", tags = "售后原因接口")
public class AfterSalesReasonController extends BladeController {

	private final IAfterSalesReasonService afterSalesReasonService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入afterSalesReason")
	public R<AfterSalesReasonVO> detail(AfterSalesReason afterSalesReason) {
		AfterSalesReason detail = afterSalesReasonService.getOne(Condition.getQueryWrapper(afterSalesReason));
		return R.data(AfterSalesReasonWrapper.build().entityVO(detail));
	}

	/**
	 * 分页 售后原因
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入afterSalesReason")
	public R<IPage<AfterSalesReasonVO>> list(AfterSalesReason afterSalesReason, Query query) {
		IPage<AfterSalesReason> pages = afterSalesReasonService.page(Condition.getPage(query), Condition.getQueryWrapper(afterSalesReason));
		return R.data(AfterSalesReasonWrapper.build().pageVO(pages));
	}


	/**
	 * 自定义分页 售后原因
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入afterSalesReason")
	public R<IPage<AfterSalesReasonVO>> page(AfterSalesReasonVO afterSalesReason, Query query) {
		IPage<AfterSalesReasonVO> pages = afterSalesReasonService.selectAfterSalesReasonPage(Condition.getPage(query), afterSalesReason);
		return R.data(pages);
	}

	/**
	 * 新增 售后原因
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入afterSalesReason")
	public R save(@Valid @RequestBody AfterSalesReason afterSalesReason) {
		return R.status(afterSalesReasonService.save(afterSalesReason));
	}

	/**
	 * 修改 售后原因
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入afterSalesReason")
	public R update(@Valid @RequestBody AfterSalesReason afterSalesReason) {
		return R.status(afterSalesReasonService.updateById(afterSalesReason));
	}

	/**
	 * 新增或修改 售后原因
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入afterSalesReason")
	public R submit(@Valid @RequestBody AfterSalesReason afterSalesReason) {
		return R.status(afterSalesReasonService.saveOrUpdate(afterSalesReason));
	}

	
	/**
	 * 删除 售后原因
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(afterSalesReasonService.removeByIds(Func.toLongList(ids)));
	}

	
}
