/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.finance.controller;

import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;

import javax.annotation.Resource;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springblade.modules.distribution.entity.Appoint;
import org.springblade.modules.distribution.service.IAppointService;
import org.springblade.modules.distribution.vo.AppointVO;
import org.springblade.modules.distribution.wrapper.AppointWrapper;
import org.springblade.modules.mall.service.IStoreService;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.finance.entity.AppointGoods;
import org.springblade.modules.finance.vo.AppointGoodsVO;
import org.springblade.modules.finance.wrapper.AppointGoodsWrapper;
import org.springblade.modules.finance.service.IAppointGoodsService;
import org.springblade.core.boot.ctrl.BladeController;

import java.util.List;
import java.util.Random;

/**
 * 分销商列表 控制器
 *
 * @author BladeX
 * @since 2023-06-07
 */
@RestController
@AllArgsConstructor
@RequestMapping("finance/appointgoods")
@Api(value = "分销商列表", tags = "分销商列表接口")
public class AppointGoodsController extends BladeController {

	private final IAppointGoodsService appointGoodsService;

	@Resource
	private IAppointService appointService;

	@Resource
	private IStoreService storeService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入appointGoods")
	public R<AppointGoodsVO> detail(AppointGoods appointGoods) {
		AppointGoods detail = appointGoodsService.getOne(Condition.getQueryWrapper(appointGoods));
		return R.data(AppointGoodsWrapper.build().entityVO(detail));
	}

	/**
	 * 分页 分销商列表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入appointGoods")
	public R<IPage<AppointGoodsVO>> list(AppointGoods appointGoods, Query query) {
		IPage<AppointGoods> pages = appointGoodsService.page(Condition.getPage(query), Condition.getQueryWrapper(appointGoods));
		return R.data(AppointGoodsWrapper.build().pageVO(pages));
	}

	@GetMapping("/appointGoodsList")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入appointGoods")
	public R<IPage<AppointVO>> appointGoodsList(@ApiParam(value = "到货码", required = true) @RequestParam String arrivalCode, Query query) {
		IPage<AppointGoods> pages = appointGoodsService.page(Condition.getPage(query),
				Wrappers.lambdaUpdate(AppointGoods.class).eq(AppointGoods::getArrivalCode, arrivalCode));
		IPage<Appoint> page = appointService.page(Condition.getPage(query), Wrappers.lambdaQuery(Appoint.class).eq(Appoint::getStoreId, storeService.getByUserId().getId()));
		IPage<AppointVO> appointVOIPage = AppointWrapper.build().pageVO(page);
		int i = 1;
		for (AppointVO record : appointVOIPage.getRecords()) {
			Random r = new Random();
			// 通过对象方法获取随机数
			int data = r.nextInt(10);
			while (data == 0){
				data = r.nextInt(10);
			}
			record.setGoodsAllNum(data);
			record.setStoreName("供应商0" + i);
			i++;
		}
		return R.data(appointVOIPage);
	}

	@GetMapping("/storeAppointGoodsList")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入appointGoods")
	public R<IPage<AppointVO>> storeAppointGoodsList(@ApiParam(value = "到货码", required = true) @RequestParam String arrivalCode, Query query) {
		IPage<AppointGoods> pages = appointGoodsService.page(Condition.getPage(query),
				Wrappers.lambdaUpdate(AppointGoods.class).eq(AppointGoods::getArrivalCode, arrivalCode));
		IPage<Appoint> page = appointService.page(Condition.getPage(query), Wrappers.lambdaQuery(Appoint.class).eq(Appoint::getStoreId, storeService.getByUserId().getId()));
		IPage<AppointVO> appointVOIPage = AppointWrapper.build().pageVO(page);
		int i = 1;
		for (AppointVO record : appointVOIPage.getRecords()) {
			Random r = new Random();
			// 通过对象方法获取随机数
			int data = r.nextInt(10);
			while (data == 0){
				data = r.nextInt(10);
			}
			if(StrUtil.isEmpty(record.getTakeTel())){
				record.setTakeTel("13500000000");
			}
			record.setGoodsAllNum(data);
			record.setTakeName("自提点名称" + i);
			record.setStoreName("供应商0" + i);
			i++;
		}
		return R.data(appointVOIPage);
	}


	/**
	 * 自定义分页 分销商列表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入appointGoods")
	public R<IPage<AppointGoodsVO>> page(AppointGoodsVO appointGoods, Query query) {
		IPage<AppointGoodsVO> pages = appointGoodsService.selectAppointGoodsPage(Condition.getPage(query), appointGoods);
		return R.data(pages);
	}

	/**
	 * 新增 分销商列表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入appointGoods")
	public R save(@Valid @RequestBody AppointGoods appointGoods) {
		return R.status(appointGoodsService.save(appointGoods));
	}

	/**
	 * 修改 分销商列表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入appointGoods")
	public R update(@Valid @RequestBody AppointGoods appointGoods) {
		return R.status(appointGoodsService.updateById(appointGoods));
	}

	/**
	 * 新增或修改 分销商列表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入appointGoods")
	public R submit(@Valid @RequestBody AppointGoods appointGoods) {
		return R.status(appointGoodsService.saveOrUpdate(appointGoods));
	}

	
	/**
	 * 删除 分销商列表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(appointGoodsService.removeByIds(Func.toLongList(ids)));
	}

	
}
