/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.finance.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.finance.entity.ConfirmOrder;
import org.springblade.modules.finance.vo.ConfirmOrderVO;
import org.springblade.modules.finance.wrapper.ConfirmOrderWrapper;
import org.springblade.modules.finance.service.IConfirmOrderService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 核销订单表 控制器
 *
 * @author BladeX
 * @since 2023-06-13
 */
@RestController
@AllArgsConstructor
@RequestMapping("finance/confirmorder")
@Api(value = "核销订单表", tags = "核销订单表接口")
public class ConfirmOrderController extends BladeController {

	private final IConfirmOrderService confirmOrderService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入confirmOrder")
	public R<ConfirmOrderVO> detail(ConfirmOrder confirmOrder) {
		ConfirmOrder detail = confirmOrderService.getOne(Condition.getQueryWrapper(confirmOrder));
		return R.data(ConfirmOrderWrapper.build().entityVO(detail));
	}

	/**
	 * 分页 核销订单表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入confirmOrder")
	public R<IPage<ConfirmOrderVO>> list(ConfirmOrder confirmOrder, Query query) {
		IPage<ConfirmOrder> pages = confirmOrderService.page(Condition.getPage(query), Condition.getQueryWrapper(confirmOrder));
		return R.data(ConfirmOrderWrapper.build().pageVO(pages));
	}


	/**
	 * 自定义分页 核销订单表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入confirmOrder")
	public R<IPage<ConfirmOrderVO>> page(ConfirmOrderVO confirmOrder, Query query) {
		IPage<ConfirmOrderVO> pages = confirmOrderService.selectConfirmOrderPage(Condition.getPage(query), confirmOrder);
		return R.data(pages);
	}

	/**
	 * 新增 核销订单表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入confirmOrder")
	public R save(@Valid @RequestBody ConfirmOrder confirmOrder) {
		return R.status(confirmOrderService.save(confirmOrder));
	}

	/**
	 * 修改 核销订单表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入confirmOrder")
	public R update(@Valid @RequestBody ConfirmOrder confirmOrder) {
		return R.status(confirmOrderService.updateById(confirmOrder));
	}

	/**
	 * 新增或修改 核销订单表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入confirmOrder")
	public R submit(@Valid @RequestBody ConfirmOrder confirmOrder) {
		return R.status(confirmOrderService.saveOrUpdate(confirmOrder));
	}

	
	/**
	 * 删除 核销订单表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(confirmOrderService.removeByIds(Func.toLongList(ids)));
	}

	
}
