/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.finance.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.finance.entity.OrderDetail;
import org.springblade.modules.finance.vo.OrderDetailVO;
import org.springblade.modules.finance.wrapper.OrderDetailWrapper;
import org.springblade.modules.finance.service.IOrderDetailService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 订单详细表 控制器
 *
 * @author BladeX
 * @since 2023-02-14
 */
@RestController
@AllArgsConstructor
@RequestMapping("finance/orderdetail")
@Api(value = "订单详细表", tags = "订单详细表接口")
public class OrderDetailController extends BladeController {

	private final IOrderDetailService orderDetailService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入orderDetail")
	public R<OrderDetailVO> detail(OrderDetail orderDetail) {
		OrderDetail detail = orderDetailService.getOne(Condition.getQueryWrapper(orderDetail));
		return R.data(OrderDetailWrapper.build().entityVO(detail));
	}

	/**
	 * 分页 订单详细表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入orderDetail")
	public R<IPage<OrderDetailVO>> list(OrderDetail orderDetail, Query query) {
		IPage<OrderDetail> pages = orderDetailService.page(Condition.getPage(query), Condition.getQueryWrapper(orderDetail));
		return R.data(OrderDetailWrapper.build().pageVO(pages));
	}


	/**
	 * 自定义分页 订单详细表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入orderDetail")
	public R<IPage<OrderDetailVO>> page(OrderDetailVO orderDetail, Query query) {
		IPage<OrderDetailVO> pages = orderDetailService.selectOrderDetailPage(Condition.getPage(query), orderDetail);
		return R.data(pages);
	}

	/**
	 * 新增 订单详细表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入orderDetail")
	public R save(@Valid @RequestBody OrderDetail orderDetail) {
		return R.status(orderDetailService.save(orderDetail));
	}

	/**
	 * 修改 订单详细表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入orderDetail")
	public R update(@Valid @RequestBody OrderDetail orderDetail) {
		return R.status(orderDetailService.updateById(orderDetail));
	}

	/**
	 * 新增或修改 订单详细表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入orderDetail")
	public R submit(@Valid @RequestBody OrderDetail orderDetail) {
		return R.status(orderDetailService.saveOrUpdate(orderDetail));
	}

	
	/**
	 * 删除 订单详细表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(orderDetailService.removeByIds(Func.toLongList(ids)));
	}

	
}
