/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.finance.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.finance.entity.OrderGroupon;
import org.springblade.modules.finance.vo.OrderGrouponVO;
import org.springblade.modules.finance.wrapper.OrderGrouponWrapper;
import org.springblade.modules.finance.service.IOrderGrouponService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 团购订单表 控制器
 *
 * @author BladeX
 * @since 2023-06-06
 */
@RestController
@AllArgsConstructor
@RequestMapping("finance/ordergroupon")
@Api(value = "团购订单表", tags = "团购订单表接口")
public class OrderGrouponController extends BladeController {

	private final IOrderGrouponService orderGrouponService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入orderGroupon")
	public R<OrderGrouponVO> detail(OrderGroupon orderGroupon) {
		OrderGroupon detail = orderGrouponService.getOne(Condition.getQueryWrapper(orderGroupon));
		return R.data(OrderGrouponWrapper.build().entityVO(detail));
	}

	/**
	 * 分页 团购订单表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入orderGroupon")
	public R<IPage<OrderGrouponVO>> list(OrderGroupon orderGroupon, Query query) {
		IPage<OrderGroupon> pages = orderGrouponService.page(Condition.getPage(query), Condition.getQueryWrapper(orderGroupon));
		return R.data(OrderGrouponWrapper.build().pageVO(pages));
	}


	/**
	 * 自定义分页 团购订单表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入orderGroupon")
	public R<IPage<OrderGrouponVO>> page(OrderGrouponVO orderGroupon, Query query) {
		IPage<OrderGrouponVO> pages = orderGrouponService.selectOrderGrouponPage(Condition.getPage(query), orderGroupon);
		return R.data(pages);
	}

	/**
	 * 新增 团购订单表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入orderGroupon")
	public R save(@Valid @RequestBody OrderGroupon orderGroupon) {
		return R.status(orderGrouponService.save(orderGroupon));
	}

	/**
	 * 修改 团购订单表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入orderGroupon")
	public R update(@Valid @RequestBody OrderGroupon orderGroupon) {
		return R.status(orderGrouponService.updateById(orderGroupon));
	}

	/**
	 * 新增或修改 团购订单表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入orderGroupon")
	public R submit(@Valid @RequestBody OrderGroupon orderGroupon) {
		return R.status(orderGrouponService.saveOrUpdate(orderGroupon));
	}

	
	/**
	 * 删除 团购订单表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(orderGrouponService.removeByIds(Func.toLongList(ids)));
	}

	
}
