/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.finance.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.AllArgsConstructor;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springblade.modules.finance.entity.TransactionFlow;
import org.springblade.modules.finance.service.ITransactionFlowService;
import org.springblade.modules.finance.vo.TransactionFlowVO;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;

/**
 * 交易流水表 控制器
 *
 * @author BladeX
 * @since 2022-08-07
 */
@RestController
@AllArgsConstructor
@RequestMapping("finance/transactionflow")
@Api(value = "交易流水表", tags = "交易流水表接口")
public class TransactionFlowController extends BladeController {

	private final ITransactionFlowService transactionFlowService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入transactionFlow")
	public R<TransactionFlow> detail(TransactionFlow transactionFlow) {
		TransactionFlow detail = transactionFlowService.getOne(Condition.getQueryWrapper(transactionFlow));
		return R.data(detail);
	}

	/**
	 * 分页 交易流水表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入transactionFlow")
	public R<IPage<TransactionFlow>> list(TransactionFlow transactionFlow, Query query) {
		IPage<TransactionFlow> pages = transactionFlowService.page(Condition.getPage(query), Condition.getQueryWrapper(transactionFlow));
		return R.data(pages);
	}

	/**
	 * 自定义分页 交易流水表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入transactionFlow")
	public R<IPage<TransactionFlowVO>> page(TransactionFlowVO transactionFlow, Query query) {
		IPage<TransactionFlowVO> pages = transactionFlowService.selectTransactionFlowPage(Condition.getPage(query), transactionFlow);
		return R.data(pages);
	}

	/**
	 * 新增 交易流水表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入transactionFlow")
	public R save(@Valid @RequestBody TransactionFlow transactionFlow) {
		return R.status(transactionFlowService.save(transactionFlow));
	}

	/**
	 * 修改 交易流水表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入transactionFlow")
	public R update(@Valid @RequestBody TransactionFlow transactionFlow) {
		return R.status(transactionFlowService.updateById(transactionFlow));
	}

	/**
	 * 新增或修改 交易流水表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入transactionFlow")
	public R submit(@Valid @RequestBody TransactionFlow transactionFlow) {
		return R.status(transactionFlowService.saveOrUpdate(transactionFlow));
	}

	
	/**
	 * 删除 交易流水表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(transactionFlowService.removeByIds(Func.toLongList(ids)));
	}

	
}
