/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.finance.mapper;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.apache.ibatis.annotations.Param;
import org.springblade.modules.api.response.UserOrderDetailResponse;
import org.springblade.modules.api.response.UserOrderResponse;
import org.springblade.modules.finance.entity.Order;
import org.springblade.modules.finance.vo.OrderVO;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.baomidou.mybatisplus.core.metadata.IPage;

import java.util.Date;
import java.util.List;

/**
 * 订单主表 Mapper 接口
 *
 * @author BladeX
 * @since 2023-02-14
 */
public interface OrderMapper extends BaseMapper<Order> {

	/**
	 * 自定义分页
	 *
	 * @param page
	 * @param order
	 * @return
	 */
	List<OrderVO> selectOrderPage(IPage page, OrderVO order);

    List<UserOrderResponse> getUserOrder(IPage<UserOrderResponse> page, Long userId, Integer orderState);

	List<UserOrderResponse> getUserAfterSalesOrder(IPage<UserOrderResponse> page, Long userId, Integer orderState);

	UserOrderDetailResponse getUserOrderDetail(Long orderId);

    Page<Order> getOrderByExpirationTime(Page page, @Param(value = "time") Date time);
}
