/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.finance.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springblade.common.enums.RefundStateEnum;
import org.springblade.modules.finance.entity.OrderRefund;
import org.springblade.modules.finance.mapper.OrderRefundMapper;
import org.springblade.modules.finance.service.IOrderRefundService;
import org.springblade.modules.finance.vo.OrderRefundVO;
import org.springframework.stereotype.Service;

import java.util.Date;

/**
 * 退款信息 服务实现类
 *
 * @author BladeX
 * @since 2022-02-13
 */
@Service
public class OrderRefundServiceImpl extends ServiceImpl<OrderRefundMapper, OrderRefund> implements IOrderRefundService {

	@Override
	public IPage<OrderRefundVO> selectOrderRefundPage(IPage<OrderRefundVO> page, OrderRefundVO orderRefund) {
		return page.setRecords(baseMapper.selectOrderRefundPage(page, orderRefund));
	}

	@Override
	public void success(OrderRefund orderRefund) {
		orderRefund.setRefundState(RefundStateEnum.SUCCESS.getValue());
		orderRefund.setAgreeTime(new Date());
		orderRefund.setRefundTime(new Date());
		this.saveOrUpdate(orderRefund);
	}

	@Override
	public void failure(OrderRefund orderRefund, String reason) {
		orderRefund.setRefundState(RefundStateEnum.FAILURE.getValue());
		orderRefund.setRefuseReason(reason);
		orderRefund.setAgreeTime(new Date());
		this.saveOrUpdate(orderRefund);
	}

}
