/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.finance.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.springblade.modules.finance.entity.Order;
import org.springblade.modules.finance.entity.PaymentRecord;
import org.springblade.modules.finance.mapper.PaymentRecordMapper;
import org.springblade.modules.finance.service.IPaymentRecordService;
import org.springblade.modules.finance.vo.PaymentRecordVO;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;

/**
 *  服务实现类
 *
 * @author BladeX
 * @since 2022-07-13
 */
@Slf4j
@Service
public class PaymentRecordServiceImpl extends ServiceImpl<PaymentRecordMapper, PaymentRecord> implements IPaymentRecordService {

	@Override
	public IPage<PaymentRecordVO> selectPaymentRecordPage(IPage<PaymentRecordVO> page, PaymentRecordVO paymentRecord) {
		return page.setRecords(baseMapper.selectPaymentRecordPage(page, paymentRecord));
	}

	@Async
	@Override
	public void init(Order order, Integer payType) {
		try {
			PaymentRecord paymentRecord = new PaymentRecord();
			paymentRecord.setOrderNo(order.getOrderNo());
			paymentRecord.setPaymentType(payType);
			paymentRecord.setPaymentPrice(order.getPaymentAmount());
			paymentRecord.setStatus(0);
			this.save(paymentRecord);
		} catch (Exception e) {
			log.error("初始化支付记录信息失败_" + e.getMessage(), e);
		}
	}

	@Async
	@Override
	public void success(String orderNo) {
		try {
			PaymentRecord record = this.lambdaQuery().eq(PaymentRecord::getOrderNo, orderNo).eq(PaymentRecord::getStatus, 0).one();
			if (record != null) {
				record.setStatus(1);
				this.updateById(record);
			}
		} catch (Exception e) {
			log.error("更新支付记录信息失败_" + e.getMessage(), e);
		}
	}

}
