/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.finance.vo;

import com.fasterxml.jackson.annotation.JsonFormat;
import org.springblade.common.enums.AfterSalesStatusEnum;
import org.springblade.common.enums.AfterSalesTypeEnum;
import org.springblade.modules.finance.entity.AfterSales;
import lombok.Data;
import lombok.EqualsAndHashCode;
import io.swagger.annotations.ApiModel;
import org.springblade.modules.finance.entity.OrderGrouponGoods;
import org.springblade.modules.finance.entity.OrderRefund;
import org.springblade.modules.mall.vo.StoreVO;

import java.util.Date;
import java.util.List;

/**
 * 售后表视图实体类
 *
 * @author BladeX
 * @since 2023-06-15
 */
@Data
@EqualsAndHashCode(callSuper = true)
@ApiModel(value = "AfterSalesVO对象", description = "售后表")
public class AfterSalesVO extends AfterSales {
	private static final long serialVersionUID = 1L;

	@JsonFormat(pattern = "MM/dd HH:mm")
	private Date grouponStartTime;
	@JsonFormat(pattern = "MM/dd HH:mm")
	private Date grouponEndTime;
	private String mainTitle;
	private String typeDesc;
	private String statusDesc;
	private List<OrderGrouponGoods> goodsList;
	private List<OrderGrouponGoodsVO> refundGoodsList;
	private Long selfTakeId;

	private OrderRefund refund;

	private OrderVO order;

	private StoreVO store;

	private String orderNo;

	public String getStatusDesc() {
		return AfterSalesStatusEnum.getNameByValue(getStatus());
	}

	public String getTypeDesc() {
		return AfterSalesTypeEnum.getNameByValue(getType());
	}
}
