/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.groupon.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;

import javax.annotation.Resource;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springblade.modules.distribution.entity.DistributionConfig;
import org.springblade.modules.distribution.service.IDistributionConfigService;
import org.springframework.context.annotation.Lazy;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.groupon.entity.Embers;
import org.springblade.modules.groupon.vo.EmbersVO;
import org.springblade.modules.groupon.wrapper.EmbersWrapper;
import org.springblade.modules.groupon.service.IEmbersService;
import org.springblade.core.boot.ctrl.BladeController;

import java.util.Calendar;
import java.util.Date;
import java.util.Objects;

/**
 * 团员列表 控制器
 *
 * @author BladeX
 * @since 2023-06-20
 */
@RestController
@AllArgsConstructor
@RequestMapping("groupon/embers")
@Api(value = "团员列表", tags = "团员列表接口")
public class EmbersController extends BladeController {

	private final IEmbersService embersService;


	@Resource
	private IDistributionConfigService distributionConfigService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入embers")
	public R<EmbersVO> detail(Embers embers) {
		Embers detail = embersService.getOne(Condition.getQueryWrapper(embers));
		return R.data(EmbersWrapper.build().entityVO(detail));
	}

	/**
	 * 分页 团员列表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入embers")
	public R<IPage<EmbersVO>> list(Embers embers, Query query) {
		IPage<Embers> pages = embersService.page(Condition.getPage(query), Condition.getQueryWrapper(embers));
		return R.data(EmbersWrapper.build().pageVO(pages));
	}


	/**
	 * 自定义分页 团员列表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入embers")
	public R<IPage<EmbersVO>> page(EmbersVO embers, Query query) {
		IPage<EmbersVO> pages = embersService.selectEmbersPage(Condition.getPage(query), embers);
		return R.data(pages);
	}

	/**
	 * 新增 团员列表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入embers")
	public R save(@Valid @RequestBody Embers embers) {
		return R.status(embersService.save(embers));
	}

	/**
	 * 修改 团员列表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入embers")
	public R update(@Valid @RequestBody Embers embers) {
		return R.status(embersService.updateById(embers));
	}

	/**
	 * 新增或修改 团员列表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入embers")
	public R submit(@Valid @RequestBody Embers embers) {
		return R.status(embersService.saveOrUpdate(embers));
	}


	/**
	 * 删除 团员列表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(embersService.removeByIds(Func.toLongList(ids)));
	}

	@PostMapping("/unbundleUser")
	@ApiOperation(value = "解绑用户")
	public void  unbundleUser(){
		DistributionConfig config = distributionConfigService.lambdaQuery()
				.eq(DistributionConfig::getIsDelete, 0)
				.one();
		if (Objects.isNull(config)){
			return;
		}
		Integer bindingDays = config.getBindingDays();
		if (Objects.isNull(bindingDays)){
			return;
		}
		//获取应当解绑的时间
		Calendar calendar = Calendar.getInstance();
		calendar.setTime(new Date());
		calendar.add(calendar.DATE,-bindingDays);
		Date time = calendar.getTime();
		embersService.unbundleUser(time);
	}



}
