/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.groupon.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;

import javax.annotation.Resource;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springblade.modules.system.entity.User;
import org.springblade.modules.system.service.IUserService;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.groupon.entity.FileContent;
import org.springblade.modules.groupon.vo.FileContentVO;
import org.springblade.modules.groupon.wrapper.FileContentWrapper;
import org.springblade.modules.groupon.service.IFileContentService;
import org.springblade.core.boot.ctrl.BladeController;

import java.util.List;

/**
 * 图文表，存储意见，投诉等信息 控制器
 *
 * @author BladeX
 * @since 2023-06-15
 */
@RestController
@AllArgsConstructor
@RequestMapping("groupon/filecontent")
@Api(value = "图文表，存储意见，投诉等信息", tags = "图文表，存储意见，投诉等信息接口")
public class FileContentController extends BladeController {

	private final IFileContentService fileContentService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入fileContent")
	public R<FileContentVO> detail(FileContent fileContent) {
		FileContent detail = fileContentService.getOne(Condition.getQueryWrapper(fileContent));
		return R.data(FileContentWrapper.build().entityVO(detail));
	}

	/**
	 * 分页 图文表，存储意见，投诉等信息
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入fileContent")
	public R<IPage<FileContentVO>> list(FileContent fileContent, Query query) {
		IPage<FileContent> pages = fileContentService.page(Condition.getPage(query), Condition.getQueryWrapper(fileContent));
		return R.data(FileContentWrapper.build().pageVO(pages));
	}


	/**
	 * 自定义分页 图文表，存储意见，投诉等信息
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入fileContent")
	public R<IPage<FileContentVO>> page(FileContentVO fileContent, Query query) {
		IPage<FileContentVO> pages = fileContentService.selectFileContentPage(Condition.getPage(query), fileContent);
		return R.data(pages);
	}

	/**
	 * 新增 图文表，存储意见，投诉等信息
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入fileContent")
	public R save(@Valid @RequestBody FileContent fileContent) {
		return R.status(fileContentService.save(fileContent));
	}

	/**
	 * 修改 图文表，存储意见，投诉等信息
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入fileContent")
	public R update(@Valid @RequestBody FileContent fileContent) {
		return R.status(fileContentService.updateById(fileContent));
	}

	/**
	 * 新增或修改 图文表，存储意见，投诉等信息
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入fileContent")
	public R submit(@Valid @RequestBody FileContent fileContent) {
		return R.status(fileContentService.saveOrUpdate(fileContent));
	}


	/**
	 * 删除 图文表，存储意见，投诉等信息
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(fileContentService.removeByIds(Func.toLongList(ids)));
	}


}
