/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.groupon.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.groupon.entity.GrouponImage;
import org.springblade.modules.groupon.vo.GrouponImageVO;
import org.springblade.modules.groupon.wrapper.GrouponImageWrapper;
import org.springblade.modules.groupon.service.IGrouponImageService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 团购图片表 控制器
 *
 * @author BladeX
 * @since 2023-06-02
 */
@RestController
@AllArgsConstructor
@RequestMapping("groupon/grouponimage")
@Api(value = "团购图片表", tags = "团购图片表接口")
public class GrouponImageController extends BladeController {

	private final IGrouponImageService grouponImageService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入grouponImage")
	public R<GrouponImageVO> detail(GrouponImage grouponImage) {
		GrouponImage detail = grouponImageService.getOne(Condition.getQueryWrapper(grouponImage));
		return R.data(GrouponImageWrapper.build().entityVO(detail));
	}

	/**
	 * 分页 团购图片表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入grouponImage")
	public R<IPage<GrouponImageVO>> list(GrouponImage grouponImage, Query query) {
		IPage<GrouponImage> pages = grouponImageService.page(Condition.getPage(query), Condition.getQueryWrapper(grouponImage));
		return R.data(GrouponImageWrapper.build().pageVO(pages));
	}


	/**
	 * 自定义分页 团购图片表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入grouponImage")
	public R<IPage<GrouponImageVO>> page(GrouponImageVO grouponImage, Query query) {
		IPage<GrouponImageVO> pages = grouponImageService.selectGrouponImagePage(Condition.getPage(query), grouponImage);
		return R.data(pages);
	}

	/**
	 * 新增 团购图片表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入grouponImage")
	public R save(@Valid @RequestBody GrouponImage grouponImage) {
		return R.status(grouponImageService.save(grouponImage));
	}

	/**
	 * 修改 团购图片表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入grouponImage")
	public R update(@Valid @RequestBody GrouponImage grouponImage) {
		return R.status(grouponImageService.updateById(grouponImage));
	}

	/**
	 * 新增或修改 团购图片表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入grouponImage")
	public R submit(@Valid @RequestBody GrouponImage grouponImage) {
		return R.status(grouponImageService.saveOrUpdate(grouponImage));
	}

	
	/**
	 * 删除 团购图片表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(grouponImageService.removeByIds(Func.toLongList(ids)));
	}

	
}
