/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.groupon.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.groupon.entity.GrouponUser;
import org.springblade.modules.groupon.vo.GrouponUserVO;
import org.springblade.modules.groupon.wrapper.GrouponUserWrapper;
import org.springblade.modules.groupon.service.IGrouponUserService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 参团用户表 控制器
 *
 * @author BladeX
 * @since 2023-06-02
 */
@RestController
@AllArgsConstructor
@RequestMapping("groupon/grouponuser")
@Api(value = "参团用户表", tags = "参团用户表接口")
public class GrouponUserController extends BladeController {

	private final IGrouponUserService grouponUserService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入grouponUser")
	public R<GrouponUserVO> detail(GrouponUser grouponUser) {
		GrouponUser detail = grouponUserService.getOne(Condition.getQueryWrapper(grouponUser));
		return R.data(GrouponUserWrapper.build().entityVO(detail));
	}

	/**
	 * 分页 参团用户表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入grouponUser")
	public R<IPage<GrouponUserVO>> list(GrouponUser grouponUser, Query query) {
		IPage<GrouponUser> pages = grouponUserService.page(Condition.getPage(query), Condition.getQueryWrapper(grouponUser));
		return R.data(GrouponUserWrapper.build().pageVO(pages));
	}


	/**
	 * 自定义分页 参团用户表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入grouponUser")
	public R<IPage<GrouponUserVO>> page(GrouponUserVO grouponUser, Query query) {
		IPage<GrouponUserVO> pages = grouponUserService.selectGrouponUserPage(Condition.getPage(query), grouponUser);
		return R.data(pages);
	}

	/**
	 * 新增 参团用户表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入grouponUser")
	public R save(@Valid @RequestBody GrouponUser grouponUser) {
		return R.status(grouponUserService.save(grouponUser));
	}

	/**
	 * 修改 参团用户表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入grouponUser")
	public R update(@Valid @RequestBody GrouponUser grouponUser) {
		return R.status(grouponUserService.updateById(grouponUser));
	}

	/**
	 * 新增或修改 参团用户表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入grouponUser")
	public R submit(@Valid @RequestBody GrouponUser grouponUser) {
		return R.status(grouponUserService.saveOrUpdate(grouponUser));
	}

	
	/**
	 * 删除 参团用户表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(grouponUserService.removeByIds(Func.toLongList(ids)));
	}

	
}
