/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.groupon.service.impl;

import cn.hutool.core.collection.CollUtil;
import org.springblade.modules.groupon.entity.GrouponImage;
import org.springblade.modules.groupon.vo.GrouponImageVO;
import org.springblade.modules.groupon.mapper.GrouponImageMapper;
import org.springblade.modules.groupon.service.IGrouponImageService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.core.metadata.IPage;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 团购图片表 服务实现类
 *
 * @author BladeX
 * @since 2023-06-02
 */
@Service
public class GrouponImageServiceImpl extends ServiceImpl<GrouponImageMapper, GrouponImage> implements IGrouponImageService {

	@Override
	public void deleteByGrouponId(Long grouponId) {
		this.baseMapper.deleteByGrouponId(grouponId);
	}

	@Override
	public IPage<GrouponImageVO> selectGrouponImagePage(IPage<GrouponImageVO> page, GrouponImageVO grouponImage) {
		return page.setRecords(baseMapper.selectGrouponImagePage(page, grouponImage));
	}

	@Override
	public Map<Long, List<String>> getByGroupIds(List<Long> grouponIds, int type) {
		List<GrouponImage> images = this.lambdaQuery().eq(GrouponImage::getType, type).in(GrouponImage::getGrouponId, grouponIds).list();
		Map<Long, List<String>> imageMaps = new HashMap<>();
		if (CollUtil.isNotEmpty(images)) {
			imageMaps = images.stream().collect(Collectors.groupingBy(GrouponImage::getGrouponId, Collectors.mapping(GrouponImage::getUrl, Collectors.toList())));
		}
		return imageMaps;
	}

}
