/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.groupon.service.impl;

import cn.hutool.core.collection.CollUtil;
import org.springblade.common.base.BaseEntity;
import org.springblade.modules.groupon.entity.GrouponUser;
import org.springblade.modules.groupon.vo.GrouponUserVO;
import org.springblade.modules.groupon.mapper.GrouponUserMapper;
import org.springblade.modules.groupon.service.IGrouponUserService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.core.metadata.IPage;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 参团用户表 服务实现类
 *
 * @author BladeX
 * @since 2023-06-02
 */
@Service
public class GrouponUserServiceImpl extends ServiceImpl<GrouponUserMapper, GrouponUser> implements IGrouponUserService {

	@Override
	public IPage<GrouponUserVO> selectGrouponUserPage(IPage<GrouponUserVO> page, GrouponUserVO grouponUser) {
		return page.setRecords(baseMapper.selectGrouponUserPage(page, grouponUser));
	}

	@Override
	public Map<Long, List<GrouponUser>> getByGroupIds(List<Long> grouponIds) {
		Map<Long, List<GrouponUser>> map = new HashMap<>();
		List<GrouponUser> list = this.lambdaQuery().in(GrouponUser::getGrouponId, grouponIds).orderByAsc(BaseEntity::getCreateTime).list();
		if (CollUtil.isNotEmpty(list)) {
			map = list.stream().collect(Collectors.groupingBy(GrouponUser::getGrouponId));
		}
		return map;
	}

}
