/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.groupon.service.impl;

import cn.hutool.core.collection.CollUtil;
import org.springblade.common.utils.DistanceUtils;
import org.springblade.modules.groupon.entity.GrouponSelfTake;
import org.springblade.modules.groupon.entity.SelfTake;
import org.springblade.modules.groupon.service.IGrouponSelfTakeService;
import org.springblade.modules.groupon.vo.SelfTakeVO;
import org.springblade.modules.groupon.mapper.SelfTakeMapper;
import org.springblade.modules.groupon.service.ISelfTakeService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springblade.modules.groupon.wrapper.SelfTakeWrapper;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.core.metadata.IPage;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 自提点表 服务实现类
 *
 * @author BladeX
 * @since 2023-06-02
 */
@Service
public class SelfTakeServiceImpl extends ServiceImpl<SelfTakeMapper, SelfTake> implements ISelfTakeService {

	@Resource
	private IGrouponSelfTakeService grouponSelfTakeService;

	@Override
	public IPage<SelfTakeVO> selectSelfTakePage(IPage<SelfTakeVO> page, SelfTakeVO selfTake) {
		return page.setRecords(baseMapper.selectSelfTakePage(page, selfTake));
	}

	@Override
	public Map<Long, List<SelfTakeVO>> getByGroupIds(List<Long> grouponIds) {
		Map<Long, List<SelfTakeVO>> map = new HashMap<>();
		List<SelfTakeVO> vos = baseMapper.getByGroupIds(grouponIds);
		if (CollUtil.isNotEmpty(vos)) {
			map = vos.stream().collect(Collectors.groupingBy(SelfTakeVO::getGrouponId));
		}
		return map;
	}

	@Override
	public List<SelfTakeVO> getSelfTakeByGrouponId(String address, Double longitude, Double latitude, Long grouponId) {
		return baseMapper.selectGrouponAllSelfTake(address, longitude, latitude, grouponId);
	}

	@Override
	public List<SelfTakeVO> getByGrouponId(Double longitude, Double latitude, Long grouponId) {
		List<GrouponSelfTake> list = grouponSelfTakeService.lambdaQuery().eq(GrouponSelfTake::getGrouponId, grouponId).list();
		if (CollUtil.isNotEmpty(list)) {
			List<Long> collect = list.stream().map(GrouponSelfTake::getSelfTakeId).collect(Collectors.toList());
			List<SelfTake> selfTakes = lambdaQuery().in(SelfTake::getId, collect).list();
			List<SelfTakeVO> selfTakeVOS = SelfTakeWrapper.build().listVO(selfTakes);
			if (longitude != null) {
				for (SelfTakeVO selfTakeVO : selfTakeVOS) {
					double distance = DistanceUtils.getDistance(longitude, latitude, selfTakeVO.getLongitude(), selfTakeVO.getLatitude());
					selfTakeVO.setDistance(distance);
				}
			}
			return selfTakeVOS;
		}
		return new ArrayList<>();
	}

}
