/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.groupon.vo;

import io.swagger.annotations.ApiModelProperty;
import org.springblade.modules.groupon.entity.SelfTake;
import lombok.Data;
import lombok.EqualsAndHashCode;
import io.swagger.annotations.ApiModel;

import java.sql.Time;

/**
 * 自提点表视图实体类
 *
 * @author BladeX
 * @since 2023-06-02
 */
@Data
@EqualsAndHashCode(callSuper = true)
@ApiModel(value = "SelfTakeVO对象", description = "自提点表")
public class SelfTakeVO extends SelfTake {
	private static final long serialVersionUID = 1L;

	private Long grouponId;

	private double distance;

	private String distanceDesc;

	private String username;

	private String qrCode;

	private String phone;

	@ApiModelProperty(value = "营业开始时间")
	private String busStartTimeDesc;

	@ApiModelProperty(value = "营业结束时间")
	private String busEndTimeDesc;

	public String getDistanceDesc() {
		if (distance  < 1) {
			return String.format("%sm", (int)(distance * 1000));
		} else {
			return String.format("%.2fkm", distance);
		}
	}

	public String getBusStartTimeDesc() {
		if (getBusStartTime() != null) {
			return getBusStartTime().toString().substring(0, 5);
		}
		return busStartTimeDesc;
	}

	public String getBusEndTimeDesc() {
		if (getBusEndTime() != null) {
			return getBusEndTime().toString().substring(0, 5);
		}
		return busEndTimeDesc;
	}
}
