/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.groupon.wrapper;

import org.springblade.core.mp.support.BaseEntityWrapper;
import org.springblade.core.tool.utils.BeanUtil;
import org.springblade.core.tool.utils.SpringUtil;
import org.springblade.modules.groupon.entity.FileContent;
import org.springblade.modules.groupon.vo.FileContentVO;
import org.springblade.modules.system.entity.User;
import org.springblade.modules.system.service.IUserService;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.Objects;

/**
 * 图文表，存储意见，投诉等信息包装类,返回视图层所需的字段
 *
 * @author BladeX
 * @since 2023-06-15
 */
public class FileContentWrapper extends BaseEntityWrapper<FileContent, FileContentVO>  {

	public static FileContentWrapper build() {
		return new FileContentWrapper();
 	}

	@Override
	public FileContentVO entityVO(FileContent fileContent) {
		FileContentVO fileContentVO = Objects.requireNonNull(BeanUtil.copy(fileContent, FileContentVO.class));
		IUserService userService = SpringUtil.getBean(IUserService.class);
		if (userService != null) {
			User user = userService.getById(fileContentVO.getCreateUserId());
			if (user != null) {
				fileContentVO.setFeedbackPerson(user.getName());
				fileContentVO.setFeedbackPersonPhone(user.getPhone());
			}
		}
		return fileContentVO;
	}

}
