/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.mall.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.mall.entity.GoodsDetail;
import org.springblade.modules.mall.vo.GoodsDetailVO;
import org.springblade.modules.mall.wrapper.GoodsDetailWrapper;
import org.springblade.modules.mall.service.IGoodsDetailService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 商品详情 控制器
 *
 * @author BladeX
 * @since 2023-06-25
 */
@RestController
@AllArgsConstructor
@RequestMapping("mall/goodsdetail")
@Api(value = "商品详情", tags = "商品详情接口")
public class GoodsDetailController extends BladeController {

	private final IGoodsDetailService goodsDetailService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入goodsDetail")
	public R<GoodsDetailVO> detail(GoodsDetail goodsDetail) {
		GoodsDetail detail = goodsDetailService.getOne(Condition.getQueryWrapper(goodsDetail));
		return R.data(GoodsDetailWrapper.build().entityVO(detail));
	}

	/**
	 * 分页 商品详情
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入goodsDetail")
	public R<IPage<GoodsDetailVO>> list(GoodsDetail goodsDetail, Query query) {
		IPage<GoodsDetail> pages = goodsDetailService.page(Condition.getPage(query), Condition.getQueryWrapper(goodsDetail));
		return R.data(GoodsDetailWrapper.build().pageVO(pages));
	}


	/**
	 * 自定义分页 商品详情
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入goodsDetail")
	public R<IPage<GoodsDetailVO>> page(GoodsDetailVO goodsDetail, Query query) {
		IPage<GoodsDetailVO> pages = goodsDetailService.selectGoodsDetailPage(Condition.getPage(query), goodsDetail);
		return R.data(pages);
	}

	/**
	 * 新增 商品详情
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入goodsDetail")
	public R save(@Valid @RequestBody GoodsDetail goodsDetail) {
		return R.status(goodsDetailService.save(goodsDetail));
	}

	/**
	 * 修改 商品详情
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入goodsDetail")
	public R update(@Valid @RequestBody GoodsDetail goodsDetail) {
		return R.status(goodsDetailService.updateById(goodsDetail));
	}

	/**
	 * 新增或修改 商品详情
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入goodsDetail")
	public R submit(@Valid @RequestBody GoodsDetail goodsDetail) {
		return R.status(goodsDetailService.saveOrUpdate(goodsDetail));
	}

	
	/**
	 * 删除 商品详情
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(goodsDetailService.removeByIds(Func.toLongList(ids)));
	}

	
}
