/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.mall.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.AllArgsConstructor;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springblade.modules.mall.entity.GoodsImg;
import org.springblade.modules.mall.service.IGoodsImgService;
import org.springblade.modules.mall.vo.GoodsImgVO;
import org.springblade.modules.mall.wrapper.GoodsImgWrapper;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;

/**
 * 商品图片(视频) 控制器
 *
 * @author BladeX
 * @since 2022-05-08
 */
@RestController
@AllArgsConstructor
@RequestMapping("mall/goodsimg")
@Api(value = "商品图片(视频)", tags = "商品图片(视频)接口")
public class GoodsImgController extends BladeController {

	private final IGoodsImgService goodsImgService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入goodsImg")
	public R<GoodsImgVO> detail(GoodsImg goodsImg) {
		GoodsImg detail = goodsImgService.getOne(Condition.getQueryWrapper(goodsImg));
		return R.data(GoodsImgWrapper.build().entityVO(detail));
	}

	/**
	 * 分页 商品图片(视频)
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入goodsImg")
	public R<IPage<GoodsImgVO>> list(GoodsImg goodsImg, Query query) {
		IPage<GoodsImg> pages = goodsImgService.page(Condition.getPage(query), Condition.getQueryWrapper(goodsImg));
		return R.data(GoodsImgWrapper.build().pageVO(pages));
	}


	/**
	 * 自定义分页 商品图片(视频)
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入goodsImg")
	public R<IPage<GoodsImgVO>> page(GoodsImgVO goodsImg, Query query) {
		IPage<GoodsImgVO> pages = goodsImgService.selectGoodsImgPage(Condition.getPage(query), goodsImg);
		return R.data(pages);
	}

	/**
	 * 新增 商品图片(视频)
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入goodsImg")
	public R save(@Valid @RequestBody GoodsImg goodsImg) {
		return R.status(goodsImgService.save(goodsImg));
	}

	/**
	 * 修改 商品图片(视频)
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入goodsImg")
	public R update(@Valid @RequestBody GoodsImg goodsImg) {
		return R.status(goodsImgService.updateById(goodsImg));
	}

	/**
	 * 新增或修改 商品图片(视频)
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入goodsImg")
	public R submit(@Valid @RequestBody GoodsImg goodsImg) {
		return R.status(goodsImgService.saveOrUpdate(goodsImg));
	}

	
	/**
	 * 删除 商品图片(视频)
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(goodsImgService.removeByIds(Func.toLongList(ids)));
	}

	
}
