/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.mall.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.AllArgsConstructor;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springblade.modules.mall.entity.GoodsParams;
import org.springblade.modules.mall.service.IGoodsParamsService;
import org.springblade.modules.mall.vo.GoodsParamsVO;
import org.springblade.modules.mall.wrapper.GoodsParamsWrapper;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

/**
 * 商品参数表 控制器
 *
 * @author BladeX
 * @since 2022-05-07
 */
@RestController
@AllArgsConstructor
@RequestMapping("mall/goodsparams")
@Api(value = "商品参数表", tags = "商品参数表接口")
public class GoodsParamsController extends BladeController {

	private final IGoodsParamsService goodsParamsService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入goodsParams")
	public R<GoodsParamsVO> detail(GoodsParams goodsParams) {
		GoodsParams detail = goodsParamsService.getOne(Condition.getQueryWrapper(goodsParams));
		return R.data(GoodsParamsWrapper.build().entityVO(detail));
	}

	/**
	 * 分页 商品参数表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入goodsParams")
	public R<IPage<GoodsParamsVO>> list(GoodsParams goodsParams, Query query) {
		IPage<GoodsParams> pages = goodsParamsService.page(Condition.getPage(query), Condition.getQueryWrapper(goodsParams));
		return R.data(GoodsParamsWrapper.build().pageVO(pages));
	}

	/**
	 * 获取商品参数
	 */
	@GetMapping("/getByGoodsId")
	@ApiOperationSupport(order = 2)
	public R<List<GoodsParams>> getByGoodsId(GoodsParams goodsParams) {
		return R.data(goodsParamsService.getByGoodsId(goodsParams.getGoodsId()));
	}


	/**
	 * 自定义分页 商品参数表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入goodsParams")
	public R<IPage<GoodsParamsVO>> page(GoodsParamsVO goodsParams, Query query) {
		IPage<GoodsParamsVO> pages = goodsParamsService.selectGoodsParamsPage(Condition.getPage(query), goodsParams);
		return R.data(pages);
	}

	/**
	 * 新增 商品参数表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入goodsParams")
	public R save(@Valid @RequestBody GoodsParams goodsParams) {
		return R.status(goodsParamsService.save(goodsParams));
	}

	/**
	 * 修改 商品参数表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入goodsParams")
	public R update(@Valid @RequestBody GoodsParams goodsParams) {
		return R.status(goodsParamsService.updateById(goodsParams));
	}

	/**
	 * 新增或修改 商品参数表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入goodsParams")
	public R submit(@Valid @RequestBody GoodsParams goodsParams) {
		return R.status(goodsParamsService.saveOrUpdate(goodsParams));
	}


	/**
	 * 删除 商品参数表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(goodsParamsService.removeByIds(Func.toLongList(ids)));
	}


}
