/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.mall.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springblade.core.tool.node.ForestNodeMerger;
import org.springblade.core.tool.node.TreeNode;
import org.springblade.core.tool.utils.Func;
import org.springblade.modules.mall.entity.CategoryInfo;
import org.springblade.modules.mall.mapper.CategoryInfoMapper;
import org.springblade.modules.mall.service.ICategoryInfoService;
import org.springblade.modules.mall.vo.CategoryInfoVO;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Map;

/**
 * 类别表 服务实现类
 *
 * @author BladeX
 * @since 2022-05-07
 */
@Service
public class CategoryInfoServiceImpl extends ServiceImpl<CategoryInfoMapper, CategoryInfo> implements ICategoryInfoService {

	private final static String PARENT_ID = "parentId";

	@Override
	public IPage<CategoryInfoVO> selectCategoryInfoPage(IPage<CategoryInfoVO> page, CategoryInfoVO categoryInfo) {
		return page.setRecords(baseMapper.selectCategoryInfoPage(page, categoryInfo));
	}

	@Override
	public List<CategoryInfoVO> lazyList(Long parentId, Map<String, Object> param) {
		if (Func.isEmpty(Func.toStr(param.get(PARENT_ID)))) {
			parentId = null;
		}
		return baseMapper.lazyList(parentId, param);
	}

	@Override
	public List<TreeNode> tree() {
		return ForestNodeMerger.merge(baseMapper.tree());
	}

	@Override
	public CategoryInfo getByNameAndLevel(String name, String level) {
		return this.baseMapper.selectOne(Wrappers.lambdaQuery(CategoryInfo.class).eq(CategoryInfo::getTitle, name).eq(CategoryInfo::getLevel, level));
	}

}
