/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.mall.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springblade.modules.mall.entity.GoodsParams;
import org.springblade.modules.mall.mapper.GoodsParamsMapper;
import org.springblade.modules.mall.service.IGoodsParamsService;
import org.springblade.modules.mall.vo.GoodsParamsVO;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 商品参数表 服务实现类
 *
 * @author BladeX
 * @since 2022-05-07
 */
@Service
public class GoodsParamsServiceImpl extends ServiceImpl<GoodsParamsMapper, GoodsParams> implements IGoodsParamsService {

	@Override
	public IPage<GoodsParamsVO> selectGoodsParamsPage(IPage<GoodsParamsVO> page, GoodsParamsVO goodsParams) {
		return page.setRecords(baseMapper.selectGoodsParamsPage(page, goodsParams));
	}

	@Override
	public void deleteByGoodsIds(List<Long> goodsIds) {
		baseMapper.delete(Wrappers.lambdaQuery(GoodsParams.class).in(GoodsParams::getGoodsId, goodsIds));
	}

	@Override
	public List<GoodsParams> getByGoodsId(Long goodsId) {
		List<GoodsParams> list = this.list(Wrappers.lambdaQuery(GoodsParams.class).
			eq(GoodsParams::getGoodsId, goodsId).orderByAsc(GoodsParams::getSort));
		return list;
	}

}
