/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.mall.vo;

import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import io.swagger.annotations.ApiModel;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.springblade.common.cache.DictCache;
import org.springblade.common.enums.DictEnum;
import org.springblade.core.tool.node.INode;
import org.springblade.modules.mall.entity.CategoryInfo;

import java.util.ArrayList;
import java.util.List;

/**
 * 类别表视图实体类
 *
 * @author BladeX
 * @since 2022-05-07
 */
@Data
@EqualsAndHashCode(callSuper = true)
@ApiModel(value = "CategoryInfoVO对象", description = "类别表")
public class CategoryInfoVO extends CategoryInfo implements INode<CategoryInfoVO> {
	private static final long serialVersionUID = 1L;
	/**
	 * 父节点ID
	 */
	@JsonSerialize(using = ToStringSerializer.class)
	private Long parentId;

	@JsonSerialize(using = ToStringSerializer.class)
	private Long key;

	/**
	 * 子孙节点
	 */
	@JsonInclude(JsonInclude.Include.NON_EMPTY)
	private List<CategoryInfoVO> children;

	/**
	 * 是否有子孙节点
	 */
	@JsonInclude(JsonInclude.Include.NON_EMPTY)
	private Boolean hasChildren;

	@Override
	public List<CategoryInfoVO> getChildren() {
		if (this.children == null) {
			this.children = new ArrayList<>();
		}
		return this.children;
	}

	private List<Long> parentIdArr;

	/**
	 * 上级
	 */
	private String parentName;

	/**
	 * 状态描述
	 */
	private String stateDesc;

	public String getStateDesc() {
		return DictCache.getValue(DictEnum.STATE, super.getState().toString());
	}
}
