/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.platform.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.platform.entity.Banks;
import org.springblade.modules.platform.vo.BanksVO;
import org.springblade.modules.platform.service.IBanksService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 银行表 控制器
 *
 * @author BladeX
 * @since 2022-02-19
 */
@RestController
@AllArgsConstructor
@RequestMapping("platform/banks")
@Api(value = "银行表", tags = "银行表接口")
public class BanksController extends BladeController {

	private final IBanksService banksService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入banks")
	public R<Banks> detail(Banks banks) {
		Banks detail = banksService.getOne(Condition.getQueryWrapper(banks));
		return R.data(detail);
	}

	/**
	 * 分页 银行表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入banks")
	public R<IPage<Banks>> list(Banks banks, Query query) {
		IPage<Banks> pages = banksService.page(Condition.getPage(query), Condition.getQueryWrapper(banks));
		return R.data(pages);
	}

	/**
	 * 自定义分页 银行表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入banks")
	public R<IPage<BanksVO>> page(BanksVO banks, Query query) {
		IPage<BanksVO> pages = banksService.selectBanksPage(Condition.getPage(query), banks);
		return R.data(pages);
	}

	/**
	 * 新增 银行表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入banks")
	public R save(@Valid @RequestBody Banks banks) {
		return R.status(banksService.save(banks));
	}

	/**
	 * 修改 银行表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入banks")
	public R update(@Valid @RequestBody Banks banks) {
		return R.status(banksService.updateById(banks));
	}

	/**
	 * 新增或修改 银行表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入banks")
	public R submit(@Valid @RequestBody Banks banks) {
		return R.status(banksService.saveOrUpdate(banks));
	}

	
	/**
	 * 删除 银行表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(banksService.removeByIds(Func.toLongList(ids)));
	}

	
}
