/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.platform.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.platform.entity.CreditRule;
import org.springblade.modules.platform.vo.CreditRuleVO;
import org.springblade.modules.platform.service.ICreditRuleService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 积分规则 控制器
 *
 * @author BladeX
 * @since 2022-03-15
 */
@RestController
@AllArgsConstructor
@RequestMapping("platform/creditrule")
@Api(value = "积分规则", tags = "积分规则接口")
public class CreditRuleController extends BladeController {

	private final ICreditRuleService creditRuleService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入creditRule")
	public R<CreditRule> detail(CreditRule creditRule) {
		CreditRule detail = creditRuleService.getOne(Condition.getQueryWrapper(creditRule));
		return R.data(detail);
	}

	/**
	 * 分页 积分规则
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入creditRule")
	public R<IPage<CreditRule>> list(CreditRule creditRule, Query query) {
		IPage<CreditRule> pages = creditRuleService.page(Condition.getPage(query), Condition.getQueryWrapper(creditRule));
		return R.data(pages);
	}

	/**
	 * 自定义分页 积分规则
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入creditRule")
	public R<IPage<CreditRuleVO>> page(CreditRuleVO creditRule, Query query) {
		IPage<CreditRuleVO> pages = creditRuleService.selectCreditRulePage(Condition.getPage(query), creditRule);
		return R.data(pages);
	}

	/**
	 * 新增 积分规则
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入creditRule")
	public R save(@Valid @RequestBody CreditRule creditRule) {
		return R.status(creditRuleService.save(creditRule));
	}

	/**
	 * 修改 积分规则
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入creditRule")
	public R update(@Valid @RequestBody CreditRule creditRule) {
		return R.status(creditRuleService.updateById(creditRule));
	}

	/**
	 * 新增或修改 积分规则
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入creditRule")
	public R submit(@Valid @RequestBody CreditRule creditRule) {
		return R.status(creditRuleService.saveOrUpdate(creditRule));
	}

	
	/**
	 * 删除 积分规则
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(creditRuleService.removeByIds(Func.toLongList(ids)));
	}

	
}
