/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.platform.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.AllArgsConstructor;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springblade.modules.platform.entity.Express;
import org.springblade.modules.platform.service.IExpressService;
import org.springblade.modules.platform.vo.ExpressVO;
import org.springblade.modules.platform.wrapper.ExpressWrapper;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

/**
 * 快递表 控制器
 *
 * @author BladeX
 * @since 2022-03-13
 */
@RestController
@AllArgsConstructor
@RequestMapping("platform/express")
@Api(value = "快递表", tags = "快递表接口")
public class ExpressController extends BladeController {

	private final IExpressService expressService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入express")
	public R<Express> detail(Express express) {
		Express detail = expressService.getOne(Condition.getQueryWrapper(express));
		return R.data(detail);
	}

	/**
	 * 分页 快递表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入express")
	public R<IPage<ExpressVO>> list(Express express, Query query) {
		IPage<Express> pages = expressService.page(Condition.getPage(query), Condition.getQueryWrapper(express));
		return R.data(ExpressWrapper.build().pageVO(pages));
	}
	/**
	 * 查询全部
	 */
	@GetMapping("/selectList")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "查询全部", notes = "传入express")
	public R<List<Express>> selectList(ExpressVO express) {
		express.setIsShow(2);//显示
		List<Express> list = expressService.list(Condition.getQueryWrapper(express));
		return R.data(list);
	}

	/**
	 * 自定义分页 快递表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入express")
	public R<IPage<ExpressVO>> page(ExpressVO express, Query query) {
		IPage<ExpressVO> pages = expressService.selectExpressPage(Condition.getPage(query), express);
		return R.data(pages);
	}

	/**
	 * 新增 快递表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入express")
	public R save(@Valid @RequestBody Express express) {
		return R.status(expressService.save(express));
	}

	/**
	 * 修改 快递表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入express")
	public R update(@Valid @RequestBody Express express) {
		return R.status(expressService.updateById(express));
	}

	/**
	 * 新增或修改 快递表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入express")
	public R submit(@Valid @RequestBody Express express) {
		return R.status(expressService.saveOrUpdate(express));
	}


	/**
	 * 删除 快递表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(expressService.removeByIds(Func.toLongList(ids)));
	}


}
