/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.platform.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.platform.entity.Message;
import org.springblade.modules.platform.vo.MessageVO;
import org.springblade.modules.platform.wrapper.MessageWrapper;
import org.springblade.modules.platform.service.IMessageService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 个人消息列表 控制器
 *
 * @author BladeX
 * @since 2023-06-11
 */
@RestController
@AllArgsConstructor
@RequestMapping("platform/message")
@Api(value = "个人消息列表", tags = "个人消息列表接口")
public class MessageController extends BladeController {

	private final IMessageService messageService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入message")
	public R<MessageVO> detail(Message message) {
		Message detail = messageService.getOne(Condition.getQueryWrapper(message));
		return R.data(MessageWrapper.build().entityVO(detail));
	}

	/**
	 * 分页 个人消息列表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入message")
	public R<IPage<MessageVO>> list(Message message, Query query) {
		IPage<Message> pages = messageService.page(Condition.getPage(query), Condition.getQueryWrapper(message));
		return R.data(MessageWrapper.build().pageVO(pages));
	}


	/**
	 * 自定义分页 个人消息列表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入message")
	public R<IPage<MessageVO>> page(MessageVO message, Query query) {
		IPage<MessageVO> pages = messageService.selectMessagePage(Condition.getPage(query), message);
		return R.data(pages);
	}

	/**
	 * 新增 个人消息列表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入message")
	public R save(@Valid @RequestBody Message message) {
		return R.status(messageService.save(message));
	}

	/**
	 * 修改 个人消息列表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入message")
	public R update(@Valid @RequestBody Message message) {
		return R.status(messageService.updateById(message));
	}

	/**
	 * 新增或修改 个人消息列表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入message")
	public R submit(@Valid @RequestBody Message message) {
		return R.status(messageService.saveOrUpdate(message));
	}

	
	/**
	 * 删除 个人消息列表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(messageService.removeByIds(Func.toLongList(ids)));
	}

	
}
