/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.platform.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.common.constant.CacheBizConstant;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.redis.cache.BladeRedis;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springblade.modules.platform.wrapper.PaymentsWrapper;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.platform.entity.Payments;
import org.springblade.modules.platform.vo.PaymentsVO;
import org.springblade.modules.platform.service.IPaymentsService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 支付方式表 控制器
 *
 * @author BladeX
 * @since 2022-02-13
 */
@RestController
@AllArgsConstructor
@RequestMapping("platform/payments")
@Api(value = "支付方式表", tags = "支付方式表接口")
public class PaymentsController extends BladeController {

	private final IPaymentsService paymentsService;
	private final BladeRedis bladeRedis;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入payments")
	public R<Payments> detail(Payments payments) {
		Payments detail = paymentsService.getOne(Condition.getQueryWrapper(payments));
		return R.data(detail);
	}

	/**
	 * 分页 支付方式表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入payments")
	public R<IPage<PaymentsVO>> list(Payments payments, Query query) {
		IPage<Payments> pages = paymentsService.page(Condition.getPage(query), Condition.getQueryWrapper(payments).lambda().orderByAsc(Payments::getSort));
		return R.data(PaymentsWrapper.build().pageVO(pages));
	}

	/**
	 * 自定义分页 支付方式表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入payments")
	public R<IPage<PaymentsVO>> page(PaymentsVO payments, Query query) {
		IPage<PaymentsVO> pages = paymentsService.selectPaymentsPage(Condition.getPage(query), payments);
		return R.data(pages);
	}

	/**
	 * 新增 支付方式表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入payments")
	public R save(@Valid @RequestBody Payments payments) {
		return R.status(paymentsService.save(payments));
	}

	/**
	 * 修改 支付方式表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入payments")
	public R update(@Valid @RequestBody Payments payments) {
		return R.status(paymentsService.updateById(payments));
	}

	/**
	 * 新增或修改 支付方式表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入payments")
	public R submit(@Valid @RequestBody Payments payments) {
		bladeRedis.del(CacheBizConstant.CACHE_DEFAULT_PAYMENTS);
		return R.status(paymentsService.saveOrUpdate(payments));
	}


	/**
	 * 删除 支付方式表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(paymentsService.removeByIds(Func.toLongList(ids)));
	}


}
