/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.platform.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.platform.entity.UserAddress;
import org.springblade.modules.platform.vo.UserAddressVO;
import org.springblade.modules.platform.service.IUserAddressService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 用户地址表 控制器
 *
 * @author BladeX
 * @since 2022-02-13
 */
@RestController
@AllArgsConstructor
@RequestMapping("platform/useraddress")
@Api(value = "用户地址表", tags = "用户地址表接口")
public class UserAddressController extends BladeController {

	private final IUserAddressService userAddressService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入userAddress")
	public R<UserAddress> detail(UserAddress userAddress) {
		UserAddress detail = userAddressService.getOne(Condition.getQueryWrapper(userAddress));
		return R.data(detail);
	}

	/**
	 * 分页 用户地址表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入userAddress")
	public R<IPage<UserAddress>> list(UserAddress userAddress, Query query) {
		IPage<UserAddress> pages = userAddressService.page(Condition.getPage(query), Condition.getQueryWrapper(userAddress));
		return R.data(pages);
	}

	/**
	 * 自定义分页 用户地址表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入userAddress")
	public R<IPage<UserAddressVO>> page(UserAddressVO userAddress, Query query) {
		IPage<UserAddressVO> pages = userAddressService.selectUserAddressPage(Condition.getPage(query), userAddress);
		return R.data(pages);
	}

	/**
	 * 新增 用户地址表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入userAddress")
	public R save(@Valid @RequestBody UserAddress userAddress) {
		return R.status(userAddressService.save(userAddress));
	}

	/**
	 * 修改 用户地址表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入userAddress")
	public R update(@Valid @RequestBody UserAddress userAddress) {
		return R.status(userAddressService.updateById(userAddress));
	}

	/**
	 * 新增或修改 用户地址表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入userAddress")
	public R submit(@Valid @RequestBody UserAddress userAddress) {
		return R.status(userAddressService.saveOrUpdate(userAddress));
	}

	
	/**
	 * 删除 用户地址表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(userAddressService.removeByIds(Func.toLongList(ids)));
	}

	
}
