/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.platform.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.platform.entity.UserCardInfo;
import org.springblade.modules.platform.vo.UserCardInfoVO;
import org.springblade.modules.platform.service.IUserCardInfoService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 用户实名认证表 控制器
 *
 * @author BladeX
 * @since 2022-03-28
 */
@RestController
@AllArgsConstructor
@RequestMapping("platform/usercardinfo")
@Api(value = "用户实名认证表", tags = "用户实名认证表接口")
public class UserCardInfoController extends BladeController {

	private final IUserCardInfoService userCardInfoService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入userCardInfo")
	public R<UserCardInfo> detail(UserCardInfo userCardInfo) {
		UserCardInfo detail = userCardInfoService.getOne(Condition.getQueryWrapper(userCardInfo));
		return R.data(detail);
	}

	/**
	 * 分页 用户实名认证表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入userCardInfo")
	public R<IPage<UserCardInfo>> list(UserCardInfo userCardInfo, Query query) {
		IPage<UserCardInfo> pages = userCardInfoService.page(Condition.getPage(query), Condition.getQueryWrapper(userCardInfo));
		return R.data(pages);
	}

	/**
	 * 自定义分页 用户实名认证表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入userCardInfo")
	public R<IPage<UserCardInfoVO>> page(UserCardInfoVO userCardInfo, Query query) {
		IPage<UserCardInfoVO> pages = userCardInfoService.selectUserCardInfoPage(Condition.getPage(query), userCardInfo);
		return R.data(pages);
	}

	/**
	 * 新增 用户实名认证表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入userCardInfo")
	public R save(@Valid @RequestBody UserCardInfo userCardInfo) {
		return R.status(userCardInfoService.save(userCardInfo));
	}

	/**
	 * 修改 用户实名认证表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入userCardInfo")
	public R update(@Valid @RequestBody UserCardInfo userCardInfo) {
		return R.status(userCardInfoService.updateById(userCardInfo));
	}

	/**
	 * 新增或修改 用户实名认证表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入userCardInfo")
	public R submit(@Valid @RequestBody UserCardInfo userCardInfo) {
		return R.status(userCardInfoService.saveOrUpdate(userCardInfo));
	}

	
	/**
	 * 删除 用户实名认证表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(userCardInfoService.removeByIds(Func.toLongList(ids)));
	}

	
}
