/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.platform.controller;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;

import javax.annotation.Resource;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springblade.modules.platform.wrapper.VersionUpgradeWrapper;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.platform.entity.VersionUpgrade;
import org.springblade.modules.platform.vo.VersionUpgradeVO;
import org.springblade.modules.platform.service.IVersionUpgradeService;
import org.springblade.core.boot.ctrl.BladeController;
import org.springframework.web.multipart.MultipartFile;

import java.io.IOException;
import java.nio.file.Paths;
import java.util.HashMap;
import java.util.Map;

/**
 * 版本升级表 控制器
 *
 * @author BladeX
 * @since 2022-03-02
 */
@RestController
@RequestMapping("platform/versionupgrade")
@Api(value = "版本升级表", tags = "版本升级表接口")
public class VersionUpgradeController extends BladeController {

	@Resource
	private IVersionUpgradeService versionUpgradeService;

	@Value("${apk.savePath}")
	private String apkSavePath;
	@Value("${apk.downloadUrl}")
	private String downloadUrl;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入versionUpgrade")
	public R<VersionUpgrade> detail(VersionUpgrade versionUpgrade) {
		VersionUpgrade detail = versionUpgradeService.getOne(Condition.getQueryWrapper(versionUpgrade));
		return R.data(detail);
	}

	/**
	 * 分页 版本升级表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入versionUpgrade")
	public R<IPage<VersionUpgradeVO>> list(VersionUpgrade versionUpgrade, Query query) {
		IPage<VersionUpgrade> pages = versionUpgradeService.page(Condition.getPage(query),
			Condition.getQueryWrapper(versionUpgrade).lambda().orderByDesc(VersionUpgrade::getStatus)
				.orderByDesc(VersionUpgrade::getVersionCode));
		return R.data(VersionUpgradeWrapper.build().pageVO(pages));
	}

	/**
	 * 自定义分页 版本升级表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入versionUpgrade")
	public R<IPage<VersionUpgradeVO>> page(VersionUpgradeVO versionUpgrade, Query query) {
		IPage<VersionUpgradeVO> pages = versionUpgradeService.selectVersionUpgradePage(Condition.getPage(query), versionUpgrade);
		return R.data(pages);
	}

	/**
	 * 新增 版本升级表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入versionUpgrade")
	public R save(@Valid @RequestBody VersionUpgrade versionUpgrade) {
		VersionUpgrade query = versionUpgradeService.getOne(Wrappers.<VersionUpgrade>lambdaQuery()
			.eq(VersionUpgrade::getVersionCode, versionUpgrade.getVersionCode()));
		if(query != null){
			return R.fail("版本编号已存在");
		}
		return R.status(versionUpgradeService.save(versionUpgrade));
	}

	/**
	 * 修改 版本升级表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入versionUpgrade")
	public R update(@Valid @RequestBody VersionUpgrade versionUpgrade) {
		return R.status(versionUpgradeService.updateById(versionUpgrade));
	}

	/**
	 * 新增或修改 版本升级表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入versionUpgrade")
	public R submit(@Valid @RequestBody VersionUpgrade versionUpgrade) {
		return R.status(versionUpgradeService.saveOrUpdate(versionUpgrade));
	}


	/**
	 * 删除 版本升级表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(versionUpgradeService.removeByIds(Func.toLongList(ids)));
	}

	@PostMapping("/uploadApk")
	public R uploadApk(MultipartFile file) throws IOException {
		file.transferTo(Paths.get(apkSavePath + file.getOriginalFilename()));
		Map<String, String> map = new HashMap<>();
		map.put("link", downloadUrl + file.getOriginalFilename());
		return R.data(map);
	}


}
