/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.platform.entity;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;

/**
 * 支付方式表实体类
 *
 * @author BladeX
 * @since 2022-02-13
 */
@Data
@TableName("t_payments")
@ApiModel(value = "Payments对象", description = "支付方式表")
public class Payments implements Serializable {

	private static final long serialVersionUID = 1L;

	/**
	 * 主键ID
	 */
	@JsonSerialize(using = ToStringSerializer.class)
	@TableId(value = "id", type = IdType.ASSIGN_ID)
	@ApiModelProperty(value = "主键ID")
	private Long id;
	/**
	 * 支付图标
	 */
	@ApiModelProperty(value = "支付图标")
	private String payImg;
	/**
	 * 支付code
	 */
	@ApiModelProperty(value = "支付code")
	private String payCode;
	/**
	 * 支付方式名称
	 */
	@ApiModelProperty(value = "支付方式名称")
	private String payName;
	/**
	 * 支付方式描述
	 */
	@ApiModelProperty(value = "支付方式描述")
	private String payDesc;
	/**
	 * 排序
	 */
	@ApiModelProperty(value = "排序")
	private Integer sort;
	/**
	 * 参数配置
	 */
	@ApiModelProperty(value = "参数配置")
	private String payConfig;
	/**
	 * 是否启用
	 */
	@ApiModelProperty(value = "是否启用")
	private Integer isEnabled;
	/**
	 * 是否在线支付
	 */
	@ApiModelProperty(value = "是否在线支付")
	private Integer isOnline;
	/**
	 * 支付端标识，1：PC端 2:手机端 3：微信端 4:APP端
	 */
	@ApiModelProperty(value = "支付端标识，1：PC端 2:手机端 3：微信端 4:APP端")
	private Integer payFor;


}
