/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.platform.entity;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
import java.time.LocalDateTime;
import java.util.Date;

/**
 * 用户地址表实体类
 *
 * @author BladeX
 * @since 2022-02-13
 */
@Data
@TableName("t_user_address")
@ApiModel(value = "UserAddress对象", description = "用户地址表")
public class UserAddress implements Serializable {

	private static final long serialVersionUID = 1L;

	/**
	 * 用户地址id
	 */
	@JsonSerialize(using = ToStringSerializer.class)
	@TableId(value = "id", type = IdType.ASSIGN_ID)
	@ApiModelProperty(value = "用户地址id")
	private Long id;
	/**
	 * 用户ID
	 */
	@ApiModelProperty(value = "用户ID")
	private Long userId;
	/**
	 * 收货人姓名
	 */
	@ApiModelProperty(value = "收货人姓名")
	private String realName;
	/**
	 * 收货人电话
	 */
	@ApiModelProperty(value = "收货人电话")
	private String phone;
	/**
	 * 收货人所在省
	 */
	@ApiModelProperty(value = "收货人所在省")
	private String province;
	/**
	 * 收货人所在市
	 */
	@ApiModelProperty(value = "收货人所在市")
	private String city;
	/**
	 * 收货人所在区
	 */
	@ApiModelProperty(value = "收货人所在区")
	private String district;
	/**
	 * 区编号
	 */
	@ApiModelProperty(value = "区编号")
	private Integer districtCode;
	/**
	 * 收货人详细地址
	 */
	@ApiModelProperty(value = "收货人详细地址")
	private String detail;
	/**
	 * 邮编
	 */
	@ApiModelProperty(value = "邮编")
	private String postCode;
	/**
	 * 经度
	 */
	@ApiModelProperty(value = "经度")
	private String lng;
	/**
	 * 纬度
	 */
	@ApiModelProperty(value = "纬度")
	private String lat;
	/**
	 * 默认标识
	 */
	@ApiModelProperty(value = "默认标识")
	private Integer defaultState;
	/**
	 * 是否删除
	 */
	@JsonIgnore
	@ApiModelProperty(value = "是否删除")
	private Integer isDeleted;
	/**
	 * 添加时间
	 */
	@ApiModelProperty(value = "添加时间")
	private Date createTime;
	/**
	 * 修改时间
	 */
	@ApiModelProperty(value = "修改时间")
	private Date updateTime;

	/**
	 * 收货人所在街道
	 */
	@ApiModelProperty(value = "收货人所在街道")
	private String street;
}
