/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.platform.entity;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
import java.time.LocalDateTime;
import java.util.Date;

/**
 * 用户反馈表实体类
 *
 * @author BladeX
 * @since 2022-02-13
 */
@Data
@TableName("t_user_feedbacks")
@ApiModel(value = "UserFeedbacks对象", description = "用户反馈表")
public class UserFeedbacks implements Serializable {

	private static final long serialVersionUID = 1L;

	/**
	 * 主键ID
	 */
	@JsonSerialize(using = ToStringSerializer.class)
	@TableId(value = "id", type = IdType.ASSIGN_ID)
	@ApiModelProperty(value = "主键ID")
	private Long id;
	/**
	 * 用户ID
	 */
	@ApiModelProperty(value = "用户ID")
	private Long userId;
	/**
	 * 反馈类型
	 */
	@ApiModelProperty(value = "反馈类型")
	private Integer type;
	/**
	 * 反馈内容
	 */
	@ApiModelProperty(value = "反馈内容")
	private String content;
	/**
	 * 联系电话
	 */
	@ApiModelProperty(value = "联系电话")
	private String phone;
	/**
	 * 记录状态：0待处理 1已处理
	 */
	@ApiModelProperty(value = "记录状态：0待处理 1已处理")
	private Integer state;
	/**
	 * 创建时间
	 */
	@ApiModelProperty(value = "创建时间")
	private Date createTime;
	/**
	 * 处理人
	 */
	@ApiModelProperty(value = "处理人")
	private Long staffId;
	/**
	 * 处理时间
	 */
	@ApiModelProperty(value = "处理时间")
	private Date handleTime;
	/**
	 * 处理内容
	 */
	@ApiModelProperty(value = "处理内容")
	private String handleContent;


}
