/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.platform.entity;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
import java.time.LocalDateTime;
import java.util.Date;

/**
 * 版本升级表实体类
 *
 * @author BladeX
 * @since 2022-03-02
 */
@Data
@TableName("blade_version_upgrade")
@ApiModel(value = "VersionUpgrade对象", description = "版本升级表")
public class VersionUpgrade implements Serializable {

	private static final long serialVersionUID = 1L;

	@JsonSerialize(using = ToStringSerializer.class)
	@TableId(value = "id", type = IdType.AUTO)
	@ApiModelProperty(value = "主键ID")
	private Long id;
	/**
	 * 小版本号
	 */
	@ApiModelProperty(value = "小版本号")
	private String versionName;
	/**
	 * 是否升级 1升级，0不升级，2强制升级
	 */
	@ApiModelProperty(value = "是否升级 1升级，0不升级，2强制升级")
	private Integer type;
	/**
	 * 更新内容
	 */
	@ApiModelProperty(value = "更新内容")
	private String content;
	/**
	 * apk路径
	 */
	@ApiModelProperty(value = "apk路径")
	private String apkUrl;
	/**
	 * 版本编号
	 */
	@ApiModelProperty(value = "版本编号")
	private Integer versionCode;
	/**
	 * APP大小
	 */
	@ApiModelProperty(value = "APP大小")
	private String apkSize;
	/**
	 * 是否启用
	 */
	@ApiModelProperty(value = "是否启用")
	private Integer status;

	@ApiModelProperty(value = "排序")
	private Integer sort;

	@ApiModelProperty(value = "创建时间")
	private Date createTime;
	/**
	 * 更新时间
	 */
	@ApiModelProperty(value = "更新时间")
	private Date updateTime;


}
