/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.platform.service.impl;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.tool.utils.DateUtil;
import org.springblade.modules.platform.entity.UserBrowse;
import org.springblade.modules.platform.vo.UserBrowseVO;
import org.springblade.modules.platform.mapper.UserBrowseMapper;
import org.springblade.modules.platform.service.IUserBrowseService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.core.metadata.IPage;

/**
 * 用户浏览记录表 服务实现类
 *
 * @author BladeX
 * @since 2022-02-13
 */
@Service
public class UserBrowseServiceImpl extends ServiceImpl<UserBrowseMapper, UserBrowse> implements IUserBrowseService {

	@Override
	public IPage<UserBrowseVO> selectUserBrowsePage(IPage<UserBrowseVO> page, UserBrowseVO userBrowse) {
		return page.setRecords(baseMapper.selectUserBrowsePage(page, userBrowse));
	}

	@Override
	public boolean userBrowse(Long userId, Long goodsId) {
		if (userId == null || goodsId == null){
			return false;
		}
		UserBrowse userBrowse = new UserBrowse();
		userBrowse.setUserId(userId);
		userBrowse.setGoodsId(goodsId);
		UserBrowse query = baseMapper.selectOne(Condition.getQueryWrapper(userBrowse));
		userBrowse.setUpdateTime(DateUtil.now());
		if (query == null){
			userBrowse.setTimes(1); //默认一次
			baseMapper.insert(userBrowse);
		}else{
			UserBrowse param = new UserBrowse();
			param.setUserId(userId);
			param.setGoodsId(goodsId);
			userBrowse.setTimes(query.getTimes() + 1); //浏览次数
			baseMapper.update(userBrowse, Condition.getQueryWrapper(param));
		}
		return true;
	}

}
