/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.platform.wrapper;

import org.springblade.common.cache.DictBizCache;
import org.springblade.common.cache.DictCache;
import org.springblade.common.enums.DictBizEnum;
import org.springblade.common.enums.DictEnum;
import org.springblade.core.mp.support.BaseEntityWrapper;
import org.springblade.core.tool.utils.BeanUtil;
import org.springblade.modules.platform.entity.Ads;
import org.springblade.modules.platform.entity.Payments;
import org.springblade.modules.platform.vo.AdsVO;
import org.springblade.modules.platform.vo.PaymentsVO;

import java.util.Objects;

/**
 * 包装类,返回视图层所需的字段
 *
 * @author Chill
 */
public class PaymentsWrapper extends BaseEntityWrapper<Payments, PaymentsVO> {

	public static PaymentsWrapper build() {
		return new PaymentsWrapper();
	}

	@Override
	public PaymentsVO entityVO(Payments entity) {
		PaymentsVO vo = Objects.requireNonNull(BeanUtil.copy(entity, PaymentsVO.class));
		vo.setIsOnlineDisplayName(DictCache.getValue(DictEnum.YES_NO,vo.getIsOnline()));
		vo.setIsEnabledDisplayName(DictCache.getValue(DictEnum.YES_NO, entity.getIsEnabled()));
		vo.setPayForDisplayName(DictBizCache.getValue(DictBizEnum.PAY_FOR, entity.getPayFor()));
		return vo;
	}

}
