/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.platform.wrapper;

import org.springblade.core.mp.support.BaseEntityWrapper;
import org.springblade.core.tool.utils.BeanUtil;
import org.springblade.core.tool.utils.SpringUtil;
import org.springblade.modules.platform.entity.Banks;
import org.springblade.modules.platform.entity.UserBankCards;
import org.springblade.modules.platform.entity.UserRecom;
import org.springblade.modules.platform.service.IBanksService;
import org.springblade.modules.platform.vo.UserBankCardsVO;
import org.springblade.modules.platform.vo.UserRecomVO;
import org.springblade.modules.system.entity.User;
import org.springblade.modules.system.service.IUserService;

import java.util.Objects;

/**
 * 包装类,返回视图层所需的字段
 *
 * @author Chill
 */
public class UserBankCardsWrapper extends BaseEntityWrapper<UserBankCards, UserBankCardsVO> {

	public static UserBankCardsWrapper build() {
		return new UserBankCardsWrapper();
	}

	public static IBanksService banksService;

	static {
		banksService = SpringUtil.getBean(IBanksService.class);
	}

	@Override
	public UserBankCardsVO entityVO(UserBankCards entity) {
		UserBankCardsVO vo = Objects.requireNonNull(BeanUtil.copy(entity, UserBankCardsVO.class));
		Banks banks = banksService.getById(entity.getBankId());
		if (banks != null){
			vo.setBankCode(banks.getBankCode());
			vo.setBankName(banks.getBankName());
			vo.setBankImg(banks.getBankImg());
		}
		return vo;
	}

}
