/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.quartz.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.quartz.entity.JobLog;
import org.springblade.modules.quartz.vo.JobLogVO;

import java.util.List;

/**
 * 定时任务调度日志表 Mapper 接口
 *
 * @author BladeX
 * @since 2023-02-17
 */
public interface JobLogMapper extends BaseMapper<JobLog> {

	/**
	 * 自定义分页
	 *
	 * @param page
	 * @param jobLog
	 * @return
	 */
	List<JobLogVO> selectJobLogPage(IPage page, JobLogVO jobLog);

	/**
	 * 获取quartz调度器日志的计划任务
	 *
	 * @param jobLog 调度日志信息
	 * @return 调度任务日志集合
	 */
	List<JobLog> selectJobLogList(JobLog jobLog);

	/**
	 * 查询所有调度任务日志
	 *
	 * @return 调度任务日志列表
	 */
	List<JobLog> selectJobLogAll();

	/**
	 * 通过调度任务日志ID查询调度信息
	 *
	 * @param jobLogId 调度任务日志ID
	 * @return 调度任务日志对象信息
	 */
	JobLog selectJobLogById(Long jobLogId);

	/**
	 * 新增任务日志
	 *
	 * @param jobLog 调度日志信息
	 * @return 结果
	 */
	int insertJobLog(JobLog jobLog);

	/**
	 * 批量删除调度日志信息
	 *
	 * @param logIds 需要删除的数据ID
	 * @return 结果
	 */
	int deleteJobLogByIds(Long[] logIds);

	/**
	 * 删除任务日志
	 *
	 * @param jobId 调度日志ID
	 * @return 结果
	 */
	int deleteJobLogById(Long jobId);

	/**
	 * 清空任务日志
	 */
	void cleanJobLog();

}
