package org.springblade.modules.quartz.service;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.IService;
import org.springblade.modules.quartz.entity.JobLog;
import org.springblade.modules.quartz.vo.JobLogVO;

import java.util.List;

/**
 * 定时任务调度日志表 服务类
 *
 * @author BladeX
 * @since 2023-02-17
 */
public interface IJobLogService extends IService<JobLog> {

	/**
	 * 自定义分页
	 *
	 * @param page
	 * @param jobLog
	 * @return
	 */
	IPage<JobLogVO> selectJobLogPage(IPage<JobLogVO> page, JobLogVO jobLog);
	/**
	 * 获取quartz调度器日志的计划任务
	 *
	 * @param jobLog 调度日志信息
	 * @return 调度任务日志集合
	 */
	List<JobLog> selectJobLogList(JobLog jobLog);

	/**
	 * 通过调度任务日志ID查询调度信息
	 *
	 * @param jobLogId 调度任务日志ID
	 * @return 调度任务日志对象信息
	 */
	JobLog selectJobLogById(Long jobLogId);

	/**
	 * 新增任务日志
	 *
	 * @param jobLog 调度日志信息
	 */
	void addJobLog(JobLog jobLog);

	/**
	 * 批量删除调度日志信息
	 *
	 * @param logIds 需要删除的日志ID
	 * @return 结果
	 */
	int deleteJobLogByIds(Long[] logIds);

	/**
	 * 删除任务日志
	 *
	 * @param jobId 调度日志ID
	 * @return 结果
	 */
	int deleteJobLogById(Long jobId);

	/**
	 * 清空任务日志
	 */
	void cleanJobLog();
}
