/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.quartz.vo;

import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModel;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.springblade.common.utils.StringUtils;
import org.springblade.modules.quartz.entity.Job;
import org.springblade.modules.quartz.utils.CronUtils;

import java.util.Date;

/**
 * 定时任务调度表视图实体类
 *
 * @author BladeX
 * @since 2023-02-17
 */
@Data
@EqualsAndHashCode(callSuper = true)
@ApiModel(value = "JobVO对象", description = "定时任务调度表")
public class JobVO extends Job {
    private static final long serialVersionUID = 1L;

    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    public Date getNextValidTime() {
        if (StringUtils.isNotEmpty(getCronExpression())) {
            return CronUtils.getNextExecution(getCronExpression());
        }
        return null;
    }
}
