/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.system.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.AllArgsConstructor;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springblade.modules.system.entity.RechargeRecord;
import org.springblade.modules.system.service.IRechargeRecordService;
import org.springblade.modules.system.vo.RechargeRecordVO;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;

/**
 * 充值记录表 控制器
 *
 * @author BladeX
 * @since 2022-08-22
 */
@RestController
@AllArgsConstructor
@RequestMapping("system/rechargerecord")
@Api(value = "充值记录表", tags = "充值记录表接口")
public class RechargeRecordController extends BladeController {

	private final IRechargeRecordService rechargeRecordService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入rechargeRecord")
	public R<RechargeRecord> detail(RechargeRecord rechargeRecord) {
		RechargeRecord detail = rechargeRecordService.getOne(Condition.getQueryWrapper(rechargeRecord));
		return R.data(detail);
	}

	/**
	 * 分页 充值记录表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入rechargeRecord")
	public R<IPage<RechargeRecord>> list(RechargeRecord rechargeRecord, Query query) {
		IPage<RechargeRecord> pages = rechargeRecordService.page(Condition.getPage(query), Condition.getQueryWrapper(rechargeRecord));
		return R.data(pages);
	}

	/**
	 * 自定义分页 充值记录表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入rechargeRecord")
	public R<IPage<RechargeRecordVO>> page(RechargeRecordVO rechargeRecord, Query query) {
		IPage<RechargeRecordVO> pages = rechargeRecordService.selectRechargeRecordPage(Condition.getPage(query), rechargeRecord);
		return R.data(pages);
	}

	/**
	 * 新增 充值记录表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入rechargeRecord")
	public R save(@Valid @RequestBody RechargeRecord rechargeRecord) {
		return R.status(rechargeRecordService.save(rechargeRecord));
	}

	/**
	 * 修改 充值记录表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入rechargeRecord")
	public R update(@Valid @RequestBody RechargeRecord rechargeRecord) {
		return R.status(rechargeRecordService.updateById(rechargeRecord));
	}

	/**
	 * 新增或修改 充值记录表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入rechargeRecord")
	public R submit(@Valid @RequestBody RechargeRecord rechargeRecord) {
		return R.status(rechargeRecordService.saveOrUpdate(rechargeRecord));
	}

	
	/**
	 * 删除 充值记录表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(rechargeRecordService.removeByIds(Func.toLongList(ids)));
	}

	
}
