/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.system.controller;

import cn.hutool.core.collection.CollUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springblade.modules.system.entity.User;
import org.springblade.modules.system.service.IUserService;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.system.entity.UserMerchant;
import org.springblade.modules.system.vo.UserMerchantVO;
import org.springblade.modules.system.wrapper.UserMerchantWrapper;
import org.springblade.modules.system.service.IUserMerchantService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 商家用户表 控制器
 *
 * @author BladeX
 * @since 2024-07-16
 */
@RestController
@AllArgsConstructor
@RequestMapping("system/usermerchant")
@Api(value = "商家用户表", tags = "商家用户表接口")
public class UserMerchantController extends BladeController {

	private final IUserMerchantService userMerchantService;
	private final IUserService iUserService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入userMerchant")
	public R<UserMerchantVO> detail(UserMerchant userMerchant) {
		UserMerchant detail = userMerchantService.getOne(Condition.getQueryWrapper(userMerchant));
		UserMerchantVO userMerchantVO = UserMerchantWrapper.build().entityVO(detail);
		User user = iUserService.getById(detail.getUserId());
		userMerchantVO.setPhone(user.getPhone());
		return R.data(userMerchantVO);
	}

	/**
	 * 分页 商家用户表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入userMerchant")
	public R<IPage<UserMerchantVO>> list(UserMerchant userMerchant, Query query) {
		IPage<UserMerchant> pages = userMerchantService.page(Condition.getPage(query), Condition.getQueryWrapper(userMerchant));
		return R.data(UserMerchantWrapper.build().pageVO(pages));
	}


	/**
	 * 自定义分页 商家用户表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入userMerchant")
	public R<IPage<UserMerchantVO>> page(UserMerchantVO userMerchant, Query query) {
		IPage<UserMerchantVO> pages = userMerchantService.selectUserMerchantPage(Condition.getPage(query), userMerchant);
		return R.data(pages);
	}

	/**
	 * 新增 商家用户表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入userMerchant")
	public R save(@Valid @RequestBody UserMerchant userMerchant) {
		return R.status(userMerchantService.save(userMerchant));
	}

	/**
	 * 修改 商家用户表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入userMerchant")
	public R update(@Valid @RequestBody UserMerchant userMerchant) {
		return R.status(userMerchantService.updateById(userMerchant));
	}

	/**
	 * 新增或修改 商家用户表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入userMerchant")
	public R submit(@Valid @RequestBody UserMerchant userMerchant) {
		return R.status(userMerchantService.saveOrUpdate(userMerchant));
	}

	
	/**
	 * 删除 商家用户表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(userMerchantService.removeByIds(Func.toLongList(ids)));
	}

	
}
