/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.system.entity;

import java.math.BigDecimal;
import com.baomidou.mybatisplus.annotation.TableName;
import java.time.LocalDateTime;
import java.io.Serializable;
import lombok.Data;
import lombok.EqualsAndHashCode;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import org.springblade.common.base.BaseEntity;

/**
 * 余额加速提现实体类
 *
 * @author BladeX
 * @since 2022-10-24
 */
@Data
@TableName("blade_withdrawal_accelerate_record")
@ApiModel(value = "WithdrawalAccelerateRecord对象", description = "余额加速提现")
public class WithdrawalAccelerateRecord extends BaseEntity<NowMoneyRecord> {

	private static final long serialVersionUID = 1L;

	/**
	* 加速人id
	*/
		@ApiModelProperty(value = "加速人id")
		private Long accelerateUserId;
	/**
	* 收益人id
	*/
		@ApiModelProperty(value = "收益人id")
		private Long benefitUserId;
	/**
	* 变动金额
	*/
		@ApiModelProperty(value = "变动金额")
		private BigDecimal amount;
	/**
	* 加速比例
	*/
		@ApiModelProperty(value = "加速比例")
		private BigDecimal ratio;
	/**
	* 加速人名称
	*/
		@ApiModelProperty(value = "加速人名称")
		private String accelerateUserName;
	/**
	* 操作前金额
	*/
		@ApiModelProperty(value = "操作前金额")
		private BigDecimal beforeAmout;
	/**
	* 操作后金额
	*/
		@ApiModelProperty(value = "操作后金额")
		private BigDecimal afterAmout;
	/**
	* 加速金额
	*/
		@ApiModelProperty(value = "加速金额")
		private BigDecimal accelerateAmount;
	/**
	* 是否使用
	*/
		@ApiModelProperty(value = "是否使用")
		private Integer isUse;
	/**
	* 使用时间
	*/
		@ApiModelProperty(value = "使用时间")
		private LocalDateTime useTime;
	/**
	* 来源记录ID
	*/
		@ApiModelProperty(value = "来源记录ID")
		private Long dataId;

	/**
	 * 加速来源：0、充值，1、预授权购买
	 */
	@ApiModelProperty(value = "加速来源：0、充值，1、预授权购买")
		private Integer src;
	/**
	* 描述
	*/
		@ApiModelProperty(value = "描述")
		private String remark;
	/**
	* 加速类型：0为加速，1为消耗
	*/
		@ApiModelProperty(value = "加速类型：0为加速，1为消耗")
		private Integer type;


}
