/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.system.service;


import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.core.mp.base.BaseService;
import org.springblade.core.mp.support.Query;
import org.springblade.modules.auth.enums.UserEnum;
import org.springblade.modules.system.entity.User;
import org.springblade.modules.system.entity.UserInfo;
import org.springblade.modules.system.entity.UserOauth;
import org.springblade.modules.system.excel.UserExcel;
import org.springblade.modules.system.vo.UserLvVo;
import org.springblade.modules.system.vo.UserVO;

import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * 服务类
 *
 * @author Chill
 */
public interface IUserService extends BaseService<User> {

	/**
	 * 新增用户
	 *
	 * @param user
	 * @return
	 */
	boolean submit(User user);

	/**
	 * 修改用户
	 *
	 * @param user
	 * @return
	 */
	boolean updateUser(User user);

	/**
	 * 修改用户基本信息
	 *
	 * @param user
	 * @return
	 */
	boolean updateUserInfo(User user);

	/**
	 * 自定义分页
	 *
	 * @param page
	 * @param user
	 * @param deptId
	 * @param tenantId
	 * @return
	 */
	IPage<User> selectUserPage(IPage<User> page, User user, Long deptId, String tenantId);

	/**
	 * 自定义分页
	 *
	 * @param user
	 * @param query
	 * @return
	 */
	IPage<UserVO> selectUserSearch(UserVO user, Query query);

	/**
	 * 根据账号获取用户
	 *
	 * @param tenantId
	 * @param account
	 * @return
	 */
	User userByAccount(String tenantId, String account);

	/**
	 * 根据手机号查询用户
	 * @param tenantId
	 * @param phone
	 * @return
	 */
	User userByPhone(String tenantId, String phone);

	/**
	 * 用户信息
	 *
	 * @param userId
	 * @return
	 */
	UserInfo userInfo(Long userId);

	/**
	 * 用户信息
	 *
	 * @param userId
	 * @return
	 */
	UserInfo userInfo(Long userId, UserEnum userEnum);

	/**
	 * 用户信息
	 *
	 * @param tenantId
	 * @param account
	 * @param password
	 * @return
	 */
	UserInfo userInfo(String tenantId, String account, String password);

	/**
	 * 用户信息
	 *
	 * @param tenantId
	 * @param account
	 * @param password
	 * @param userEnum
	 * @return
	 */
	UserInfo userInfo(String tenantId, String account, String password, UserEnum userEnum);

	/**
	 * 用户信息
	 *
	 * @param userOauth
	 * @return
	 */
	UserInfo userInfo(UserOauth userOauth);

	/**
	 * 给用户设置角色
	 *
	 * @param userIds
	 * @param roleIds
	 * @return
	 */
	boolean grant(String userIds, String roleIds);

	/**
	 * 初始化密码
	 *
	 * @param userIds
	 * @return
	 */
	boolean resetPassword(String userIds);

	/**
	 * 通过用户id重置用户密码
	 * @param userId
	 * @return
	 */
	boolean resetPasswordById(Long userId);

	/**
	 * 修改密码
	 *
	 * @param userId
	 * @param oldPassword
	 * @param newPassword
	 * @param newPassword1
	 * @return
	 */
	boolean updatePassword(Long userId, String oldPassword, String newPassword, String newPassword1);

	/**
	 * 删除用户
	 *
	 * @param userIds
	 * @return
	 */
	boolean removeUser(String userIds);

	/**
	 * 导入用户数据
	 *
	 * @param data
	 * @param isCovered
	 * @return
	 */
	void importUser(List<UserExcel> data, Boolean isCovered);

	/**
	 * 导出用户数据
	 *
	 * @param queryWrapper
	 * @return
	 */
	List<UserExcel> exportUser(Wrapper<User> queryWrapper);

	/**
	 * 注册用户
	 *
	 * @param user
	 * @param oauthId
	 * @return
	 */
	boolean registerGuest(User user, Long oauthId);

	/**
	 * 注册用户
	 *
	 * @param user
	 * @return
	 */
	boolean registerApp(User user, Long parentId);

	/**
	 * 注册用户
	 *
	 * @param userId   用户ID
	 * @param password 密码
	 * @return
	 */
	boolean resetPassword(Long userId, String password);

	/**
	 * 配置用户平台
	 *
	 * @param userId
	 * @param userType
	 * @param userExt
	 * @return
	 */
	boolean updatePlatform(Long userId, Integer userType, String userExt);

	/**
	 * 用户详细信息
	 *
	 * @param user
	 * @return
	 */
	UserVO platformDetail(User user);


    Map<Integer, List<UserLvVo>> getUserTree(Long userId);

	/**
	 * 找出符合直推创客人数条件的用户
	 * @param userIds 用户查询用户id列表
	 * @param num 创客数量
	 * @return
	 */
	List<Long> getMakerList(List<Long> userIds, Integer num);

	/**
	 * 找出符合团队人数条件的用户
	 * @param userIds 用户查询用户id列表
	 * @param num 创客数量
	 * @return
	 */
	List<Long> getTeamList(List<Long> userIds, Integer num);

	/**
	 * 找出符合团队购买数量达标的客户id
	 * @param userIds 用户查询用户id列表
	 * @param num 创客数量
	 * @param consignDate 购买时间
	 * @return
	 */
	List<Long> getTeamConsignList(List<Long> userIds, Integer num, Date consignDate);

	/**
	 * 找出符合直推购买数量达标的客户id
	 * @param userIds 用户查询用户id列表
	 * @param num 创客数量
	 * @param consignDate 购买时间
	 * @return
	 */
	List<Long> getRecomConsignList(List<Long> userIds, Integer num, Date consignDate);

	/**
	 * 找出符合轰动条件条件的用户
	 * @param userIds 用户查询用户id列表
	 * @return
	 */
	List<Long> getNewList(List<Long> userIds);

	/**
	 * 查询当天用户的团队和直推人员购买数量
	 * @param userId 用户id
	 * @param consignDate 购买时间
	 * @param consignConfigId 场次id
	 * @return
	 */
	List<Map<String,String>> countRecomAndTeamConsign(Long userId, Date consignDate, Long consignConfigId);

	User getByAccount(String account);

	/**
	 * 添加角色
	 * @param userId
	 */
	void setRoleByRoleName(Long userId, String roleName);

	/**
	 * 移除角色
	 * @param userId
	 */
	void removeRoleByRoleName(Long userId, String roleName);
}
